@@ -476,8 +476,7 @@ show_session_error (GtkWindow *parent,
 
     case ERR_FILEIO_RESERVED_WRITE:
         /* Translators: the first %s is a path in the filesystem,
-         * the second %s is PACKAGE_NAME, which by default is "GnuCash"
-         */
+           the second %s is PACKAGE_NAME, which by default is "GnuCash" */
         fmt = _("You attempted to save in\n%s\nor a subdirectory thereof. "
                 "This is not allowed as %s reserves that directory for internal use.\n\n"
                 "Please try again in a different directory.");
@@ -505,7 +504,7 @@ show_session_error (GtkWindow *parent,
     case ERR_SQL_DB_BUSY:
         fmt = _("The SQL database is in use by other users, "
                 "and the upgrade cannot be performed until they logoff. "
-                "If there are currently no other users, consult the  "
+                "If there are currently no other users, consult the "
                 "documentation to learn how to clear out dangling login "
                 "sessions.");
         gnc_error_dialog (parent, "%s", fmt);
@@ -695,10 +694,11 @@ gnc_file_query_save (GtkWindow *parent, gboolean can_cancel)
 
 /* private utilities for file open; done in two stages */
 
-#define RESPONSE_NEW  1
+#define RESPONSE_NEW 1
 #define RESPONSE_OPEN 2
 #define RESPONSE_QUIT 3
 #define RESPONSE_READONLY 4
+#define RESPONSE_FILE 5
 
 static gboolean
 gnc_post_file_open (GtkWindow *parent, const char * filename, gboolean is_readonly)
@@ -846,22 +846,34 @@ RESTART:
                 "%s", fmt2);
         gtk_window_set_skip_taskbar_hint(GTK_WINDOW(dialog), FALSE);
 
-        gnc_gtk_dialog_add_button(dialog, _("_Open Read-Only"),
-                                  "document-revert", RESPONSE_READONLY);
-        gnc_gtk_dialog_add_button(dialog, _("_Create New File"),
-                                  "document-new", RESPONSE_NEW);
+        gnc_gtk_dialog_add_button(dialog, _("Open _Read-Only"),
+                                  "emblem-readonly", RESPONSE_READONLY);
+
+        gnc_gtk_dialog_add_button(dialog, _("Create _New File"),
+                                  "document-new-symbolic", RESPONSE_NEW);
+
         gnc_gtk_dialog_add_button(dialog, _("Open _Anyway"),
-                                  "document-open", RESPONSE_OPEN);
+                                  "document-open-symbolic", RESPONSE_OPEN);
+
+        gnc_gtk_dialog_add_button(dialog, _("Open _Folder"),
+                                  "folder-open-symbolic", RESPONSE_FILE);
+
         if (shutdown_cb)
+        {
             gtk_dialog_add_button(GTK_DIALOG(dialog),
                                   _("_Quit"), RESPONSE_QUIT);
+            gtk_dialog_set_default_response (GTK_DIALOG(dialog), RESPONSE_QUIT);
+        }
+        else
+            gtk_dialog_set_default_response (GTK_DIALOG(dialog), RESPONSE_FILE);
+
         rc = gtk_dialog_run(GTK_DIALOG(dialog));
         gtk_widget_destroy(dialog);
         g_free (displayname);
 
         if (rc == GTK_RESPONSE_DELETE_EVENT)
         {
-            rc = shutdown_cb ? RESPONSE_QUIT : RESPONSE_NEW;
+            rc = shutdown_cb ? RESPONSE_QUIT : RESPONSE_FILE;
         }
         switch (rc)
         {
@@ -879,13 +891,20 @@ RESTART:
             /* user told us to ignore locks. So ignore them. */
             qof_session_begin (new_session, newfile, SESSION_BREAK_LOCK);
             break;
-        default:
+        case RESPONSE_NEW:
             /* Can't use the given file, so just create a new
              * database so that the user will get a window that
              * they can click "Exit" on.
              */
             gnc_file_new (parent);
             break;
+        default:
+            /* Can't use the given file, so open a file browser dialog
+             * so they can choose a different file and get a window that
+             * they can click "Exit" on.
+             */
+            gnc_file_open (parent);
+            break;
         }
     }
     /* if the database doesn't exist, ask the user ... */
@@ -1669,7 +1688,7 @@ gnc_file_revert (GtkWindow *parent)
 {
     QofSession *session;
     const gchar *fileurl, *filename, *tmp;
-    const gchar *title = _("Reverting will discard all unsaved changes to %s. Are you sure you want to proceed ?");
+    const gchar *title = _("Reverting will discard all unsaved changes to %s. Are you sure you want to proceed?");
 
     if (!gnc_main_window_all_finish_pending())
         return;
