@@ -27,13 +27,15 @@ extern "C" {
 #include <windows.h>
 #endif
 
-#include <glib.h>
-#include <glib/gi18n.h>
-
 #include "engine-helpers.h"
 #include "gnc-ui-util.h"
 }
 
+#include <glib.h>
+#include <glib/gi18n.h>
+
+#include <exception>
+#include <map>
 #include <string>
 #include <boost/regex.hpp>
 #include <boost/regex/icu.hpp>
@@ -46,7 +48,8 @@ std::map<GncPricePropType, const char*> gnc_price_col_type_strs = {
         { GncPricePropType::NONE, N_("None") },
         { GncPricePropType::DATE, N_("Date") },
         { GncPricePropType::AMOUNT, N_("Amount") },
-        { GncPricePropType::FROM_COMMODITY, N_("Commodity From") },
+        { GncPricePropType::FROM_SYMBOL, N_("From Symbol") },
+        { GncPricePropType::FROM_NAMESPACE, N_("From Namespace") },
         { GncPricePropType::TO_CURRENCY, N_("Currency To") },
 };
 
@@ -90,43 +93,28 @@ GncNumeric parse_amount_price (const std::string &str, int currency_format)
     return GncNumeric(val);
 }
 
-/** Convert comm_str into a gnc_commodity.
- * @param comm_str The string to be parsed
+/** Convert the combination of symbol_str and namespace_str into a gnc_commodity.
+ * @param symbol_str The symbol string to be parsed
+ * @param namespace_str The Namespace for this commodity
  * @return a gnc_commodity
  * @exception May throw std::invalid argument if string can't be parsed properly
  */
-gnc_commodity* parse_commodity_price_comm (const std::string& comm_str)
+gnc_commodity* parse_commodity_price_comm (const std::string& symbol_str, const std::string& namespace_str)
 {
-    if (comm_str.empty())
+    if (symbol_str.empty())
         return nullptr;
 
     auto table = gnc_commodity_table_get_table (gnc_get_current_book());
     gnc_commodity* comm = nullptr;
 
-    /* First try commodity as a unique name. */
-    if (comm_str.find("::"))
-        comm = gnc_commodity_table_lookup_unique (table, comm_str.c_str());
-
-    /* Then try mnemonic in the currency namespace */
-    if (!comm)
-        comm = gnc_commodity_table_lookup (table,
-                GNC_COMMODITY_NS_CURRENCY, comm_str.c_str());
+    /* First try commodity as a unique name, used in loading settings, returns null if not found */
+    comm = gnc_commodity_table_lookup_unique (table, symbol_str.c_str());
 
+    /* Now lookup with namespace and symbol */
     if (!comm)
     {
-        /* If that fails try mnemonic in all other namespaces */
-        auto namespaces = gnc_commodity_table_get_namespaces(table);
-        for (auto ns = namespaces; ns; ns = ns->next)
-        {
-            gchar* ns_str = (gchar*)ns->data;
-            if (g_utf8_collate(ns_str, GNC_COMMODITY_NS_CURRENCY) == 0)
-                continue;
-
-            comm = gnc_commodity_table_lookup (table,
-                    ns_str, comm_str.c_str());
-            if (comm)
-                break;
-        }
+        comm = gnc_commodity_table_lookup (table,
+                    namespace_str.c_str(), symbol_str.c_str());
     }
 
     if (!comm)
@@ -135,6 +123,26 @@ gnc_commodity* parse_commodity_price_comm (const std::string& comm_str)
         return comm;
 }
 
+/** Check for a valid namespace.
+ * @param namespace_str The string to be parsed
+ * @return a bool
+ * @exception May throw std::invalid argument if string can't be parsed properly
+ */
+bool parse_namespace (const std::string& namespace_str)
+{
+    if (namespace_str.empty())
+        return false;
+
+    auto table = gnc_commodity_table_get_table (gnc_get_current_book());
+
+    if (gnc_commodity_table_has_namespace (table, namespace_str.c_str()))
+        return true;
+    else
+        throw std::invalid_argument (_("Value can't be parsed into a valid namespace."));
+
+    return false;
+}
+
 void GncImportPrice::set (GncPricePropType prop_type, const std::string& value, bool enable_test_empty)
 {
     try
@@ -159,24 +167,56 @@ void GncImportPrice::set (GncPricePropType prop_type, const std::string& value,
                 m_amount = parse_amount_price (value, m_currency_format); // Throws if parsing fails
                 break;
 
-            case GncPricePropType::FROM_COMMODITY:
-                m_from_commodity = boost::none;
-                comm = parse_commodity_price_comm (value); // Throws if parsing fails
-                if (comm)
+            case GncPricePropType::FROM_SYMBOL:
+                m_from_symbol = boost::none;
+
+                if (value.empty())
+                    throw std::invalid_argument (_("'From Symbol' can not be empty."));
+                else
+                    m_from_symbol = value;
+
+                if (m_from_namespace)
                 {
-                    if (m_to_currency == comm)
-                        throw std::invalid_argument (_("'Commodity From' can not be the same as 'Currency To' column type."));
-                    m_from_commodity = comm;
+                    comm = parse_commodity_price_comm (value, *m_from_namespace); // Throws if parsing fails
+                    if (comm)
+                    {
+                        if (m_to_currency == comm)
+                                throw std::invalid_argument (_("'Commodity From' can not be the same as 'Currency To'."));
+                        m_from_commodity = comm;
+                    }
+                }
+                break;
+
+            case GncPricePropType::FROM_NAMESPACE:
+                m_from_namespace = boost::none;
+
+                if (value.empty())
+                    throw std::invalid_argument (_("'From Namespace' can not be empty."));
+
+                if (parse_namespace (value)) // Throws if parsing fails
+                {
+                    m_from_namespace = value;
+
+                    if (m_from_symbol)
+                    {
+                        comm = parse_commodity_price_comm (*m_from_symbol, *m_from_namespace); // Throws if parsing fails
+                        if (comm)
+                        {
+                            if (m_to_currency == comm)
+                                throw std::invalid_argument (_("'Commodity From' can not be the same as 'Currency To'."));
+                            m_from_commodity = comm;
+                        }
+                    }
                 }
                 break;
 
             case GncPricePropType::TO_CURRENCY:
                 m_to_currency = boost::none;
-                comm = parse_commodity_price_comm (value); // Throws if parsing fails
+                comm = parse_commodity_price_comm (value, GNC_COMMODITY_NS_CURRENCY); // Throws if parsing fails
                 if (comm)
                 {
                     if (m_from_commodity == comm)
-                        throw std::invalid_argument (_("'Currency To' can not be the same as 'Commodity From' column type."));
+                        throw std::invalid_argument (_("'Currency To' can not be the same as 'Commodity From'."));
                     if (gnc_commodity_is_currency (comm) != true)
                         throw std::invalid_argument (_("Value parsed into an invalid currency for a currency column type."));
                     m_to_currency = comm;
@@ -211,6 +251,13 @@ void GncImportPrice::reset (GncPricePropType prop_type)
 {
     try
     {
+        if ((prop_type == GncPricePropType::FROM_NAMESPACE) ||
+            (prop_type == GncPricePropType::FROM_SYMBOL))
+             set_from_commodity (nullptr);
+
+        if (prop_type == GncPricePropType::TO_CURRENCY)
+             set_to_currency (nullptr);
+
         // set enable_test_empty to false to allow empty values
         set (prop_type, std::string(), false);
     }
@@ -230,9 +277,9 @@ std::string GncImportPrice::verify_essentials (void)
     else if (m_amount == boost::none)
         return _("No amount column.");
     else if (m_to_currency == boost::none)
-        return _("No 'Currency to' column.");
+        return _("No 'Currency to'.");
     else if (m_from_commodity == boost::none)
-        return _("No 'Commodity from' column.");
+        return _("No 'Commodity from'.");
     else if (gnc_commodity_equal (*m_from_commodity, *m_to_currency))
         return _("'Commodity From' can not be the same as 'Currency To'.");
     else
@@ -253,14 +300,13 @@ Result GncImportPrice::create_price (QofBook* book, GNCPriceDB *pdb, bool over)
 
     auto date = static_cast<time64>(GncDateTime(*m_date, DayPart::neutral));
 
-    bool rev = false;
     auto amount = *m_amount;
     Result ret_val = ADDED;
 
     GNCPrice *old_price = gnc_pricedb_lookup_day_t64 (pdb, *m_from_commodity,
                                                       *m_to_currency, date);
 
-    // Should old price be over writen
+    // Should old price be over written
     if ((old_price != nullptr) && (over == true))
     {
         DEBUG("Over write");
@@ -270,27 +316,11 @@ Result GncImportPrice::create_price (QofBook* book, GNCPriceDB *pdb, bool over)
         ret_val = REPLACED;
     }
 
-    if (gnc_commodity_is_currency (*m_from_commodity)) // Currency Import
-    {
-        // Check for currency in reverse direction.
-        if (old_price != nullptr)
-        {
-            // Check for price in reverse direction.
-            if (gnc_commodity_equiv (gnc_price_get_currency (old_price), *m_from_commodity))
-                rev = true;
-        }
-        DEBUG("Commodity from is a Currency");
-
-        // Check for price less than 1, reverse if so.
-        if (*m_amount < GncNumeric(1,1))
-            rev = true;
-
-    }
     char date_str [MAX_DATE_LENGTH + 1];
     memset (date_str, 0, sizeof(date_str));
-    qof_print_date_buff (date_str, sizeof(date_str), date);
-    DEBUG("Date is %s, Rev is %d, Commodity from is '%s', Currency is '%s', "
-          "Amount is %s", date_str, rev,
+    qof_print_date_buff (date_str, MAX_DATE_LENGTH, date);
+    DEBUG("Date is %s, Commodity from is '%s', Currency is '%s', "
+          "Amount is %s", date_str,
           gnc_commodity_get_fullname (*m_from_commodity),
           gnc_commodity_get_fullname (*m_to_currency),
           amount.to_string().c_str());
@@ -300,23 +330,17 @@ Result GncImportPrice::create_price (QofBook* book, GNCPriceDB *pdb, bool over)
         DEBUG("Create");
         GNCPrice *price = gnc_price_create (book);
         gnc_price_begin_edit (price);
-        if (rev)
-        {
-            amount = amount.inv(); //invert the amount
-            gnc_price_set_commodity (price, *m_to_currency);
-            gnc_price_set_currency (price, *m_from_commodity);
-        }
-        else
-        {
-            gnc_price_set_commodity (price, *m_from_commodity);
-            gnc_price_set_currency (price, *m_to_currency);
-        }
-        auto amount_conv = amount.convert<RoundType::half_up>(CURRENCY_DENOM);
+
+        gnc_price_set_commodity (price, *m_from_commodity);
+        gnc_price_set_currency (price, *m_to_currency);
+
+        int scu = gnc_commodity_get_fraction (*m_to_currency);
+        auto amount_conv = amount.convert<RoundType::half_up>(scu * COMMODITY_DENOM_MULT);
+
         gnc_price_set_value (price, static_cast<gnc_numeric>(amount_conv));
 
         gnc_price_set_time64 (price, date);
         gnc_price_set_source (price, PRICE_SOURCE_USER_PRICE);
-//FIXME Not sure which one        gnc_price_set_source (price, PRICE_SOURCE_FQ);
         gnc_price_set_typestr (price, PRICE_TYPE_LAST);
         gnc_price_commit_edit (price);
 
