@@ -26,8 +26,6 @@ extern "C" {
 #include <windows.h>
 #endif
 
-#include <glib.h>
-#include <glib/gi18n.h>
 
 #include "engine-helpers.h"
 #include "gnc-csv-account-map.h"
@@ -39,7 +37,15 @@ extern "C" {
 
 }
 
+#include <glib.h>
+#include <glib/gi18n.h>
+
+#include <algorithm>
+#include <exception>
+#include <map>
 #include <string>
+#include <vector>
+
 #include <boost/regex.hpp>
 #include <boost/regex/icu.hpp>
 #include "gnc-imp-props-tx.hpp"
