@@ -68,15 +68,16 @@ struct _main_matcher_info
     GNCTransactionProcessedCB transaction_processed_cb;
     gpointer user_data;
     GNCImportPendingMatches *pending_matches;
-    GtkTreeViewColumn *account_column;
-    GtkWidget         *show_account_column;
-    GtkWidget         *show_matched_info;
-    GtkWidget         *reconcile_after_close;
-    gboolean add_toggled;   // flag to indicate that add has been toggled to stop selection
+    GtkTreeViewColumn       *account_column;
+    GtkTreeViewColumn       *memo_column;
+    GtkWidget               *show_account_column;
+    GtkWidget               *show_matched_info;
+    GtkWidget               *reconcile_after_close;
+    gboolean add_toggled;     // flag to indicate that add has been toggled to stop selection
     gint id;
-    GSList* temp_trans_list; // Temporary list of imported transactions
-    GHashTable* acct_id_hash;     // Hash table, per account, of list of transaction IDs.
-    GSList* edited_accounts; // List of accounts currently edited.
+    GSList* temp_trans_list;  // Temporary list of imported transactions
+    GHashTable* acct_id_hash; // Hash table, per account, of list of transaction IDs.
+    GSList* edited_accounts;  // List of accounts currently edited.
 };
 
 enum downloaded_cols
@@ -117,37 +118,36 @@ void on_matcher_help_close_clicked (GtkButton *button, gpointer user_data);
 static void gnc_gen_trans_list_create_matches (GNCImportMainMatcher *gui);
 
 /* Local prototypes */
-static void gnc_gen_trans_assign_transfer_account (
-                    GtkTreeView *treeview,
-                    gboolean *first,
-                    gboolean is_selection,
-                    GtkTreePath *path,
-                    Account **new_acc,
-                    GNCImportMainMatcher *info);
-static void gnc_gen_trans_assign_transfer_account_to_selection_cb (
-                    GtkMenuItem *menuitem,
-                    GNCImportMainMatcher *info);
-static void gnc_gen_trans_view_popup_menu (
-                    GtkTreeView *treeview,
-                    GdkEvent *event,
-                    GNCImportMainMatcher *info);
-static gboolean gnc_gen_trans_onButtonPressed_cb (
-                    GtkTreeView *treeview,
-                    GdkEvent *event,
-                    GNCImportMainMatcher *info);
-static gboolean gnc_gen_trans_onPopupMenu_cb (
-                    GtkTreeView *treeview,
-                    GNCImportMainMatcher *info);
-static void refresh_model_row (
-                    GNCImportMainMatcher *gui,
-                    GtkTreeModel *model,
-                    GtkTreeIter *iter,
-                    GNCImportTransInfo *info);
+static void gnc_gen_trans_assign_transfer_account (GtkTreeView *treeview,
+                                                   gboolean *first,
+                                                   gboolean is_selection,
+                                                   GtkTreePath *path,
+                                                   Account **new_acc,
+                                                   GNCImportMainMatcher *info);
+static void gnc_gen_trans_assign_transfer_account_to_selection_cb (GtkMenuItem *menuitem,
+                                                                   GNCImportMainMatcher *info);
+static void gnc_gen_trans_view_popup_menu (GtkTreeView *treeview,
+                                           GdkEvent *event,
+                                           GNCImportMainMatcher *info);
+static gboolean gnc_gen_trans_onButtonPressed_cb (GtkTreeView *treeview,
+                                                  GdkEvent *event,
+                                                  GNCImportMainMatcher *info);
+static gboolean gnc_gen_trans_onPopupMenu_cb (GtkTreeView *treeview,
+                                              GNCImportMainMatcher *info);
+static void refresh_model_row (GNCImportMainMatcher *gui,
+                               GtkTreeModel *model,
+                               GtkTreeIter *iter,
+                               GNCImportTransInfo *info);
+static gboolean query_tooltip_tree_view_cb (GtkWidget *widget, gint x, gint y,
+                                            gboolean keyboard_tip,
+                                            GtkTooltip *tooltip,
+                                            gpointer user_data);
 /* end local prototypes */
 
-static gboolean delete_hash (gpointer key, gpointer value, gpointer user_data)
+static
+gboolean delete_hash (gpointer key, gpointer value, gpointer user_data)
 {
-    // Value is a hash table that needs to be destroyed. 
+    // Value is a hash table that needs to be destroyed.
     g_hash_table_destroy (value);
     return TRUE;
 }
@@ -157,8 +157,8 @@ update_all_balances (GNCImportMainMatcher *info)
 {
     for (GSList* iter = info->edited_accounts; iter; iter=iter->next)
     {
-        gnc_account_set_defer_bal_computation(iter->data,FALSE);
-        xaccAccountRecomputeBalance(iter->data);
+        gnc_account_set_defer_bal_computation (iter->data,FALSE);
+        xaccAccountRecomputeBalance (iter->data);
     }
     g_slist_free (info->edited_accounts);
     info->edited_accounts = NULL;
@@ -167,14 +167,15 @@ update_all_balances (GNCImportMainMatcher *info)
 static void
 defer_bal_computation (GNCImportMainMatcher *info, Account* acc)
 {
-    if (!gnc_account_get_defer_bal_computation(acc))
+    if (!gnc_account_get_defer_bal_computation (acc))
     {
         gnc_account_set_defer_bal_computation (acc, TRUE);
         info->edited_accounts = g_slist_prepend (info->edited_accounts, acc);
     }
 }
 
-void gnc_gen_trans_list_delete (GNCImportMainMatcher *info)
+void
+gnc_gen_trans_list_delete (GNCImportMainMatcher *info)
 {
     GtkTreeModel *model;
     GtkTreeIter iter;
@@ -206,23 +207,24 @@ void gnc_gen_trans_list_delete (GNCImportMainMatcher *info)
         gnc_save_window_size (GNC_PREFS_GROUP, GTK_WINDOW(info->main_widget));
         gnc_import_Settings_delete (info->user_settings);
         gnc_unregister_gui_component (info->id);
-        gtk_widget_destroy (GTK_WIDGET (info->main_widget));
+        gtk_widget_destroy (GTK_WIDGET(info->main_widget));
     }
     else
         gnc_import_Settings_delete (info->user_settings);
 
-    g_slist_free_full (info->temp_trans_list,(GDestroyNotify) gnc_import_TransInfo_delete);
+    g_slist_free_full (info->temp_trans_list, (GDestroyNotify) gnc_import_TransInfo_delete);
     info->temp_trans_list = NULL;
-    
+
     // We've deferred balance computations on many accounts. Let's do it now that we're done.
     update_all_balances (info);
-    
+
     g_hash_table_foreach_remove (info->acct_id_hash, delete_hash, NULL);
     info->acct_id_hash = NULL;
     g_free (info);
 }
 
-gboolean gnc_gen_trans_list_empty(GNCImportMainMatcher *info)
+gboolean
+gnc_gen_trans_list_empty (GNCImportMainMatcher *info)
 {
     GtkTreeModel *model;
     GtkTreeIter iter;
@@ -233,6 +235,60 @@ gboolean gnc_gen_trans_list_empty(GNCImportMainMatcher *info)
     return !gtk_tree_model_get_iter_first (model, &iter) && !info->temp_trans_list;
 }
 
+static void
+gnc_gen_trans_list_show_accounts_column (GNCImportMainMatcher *info)
+{
+    GtkTreeModel *model;
+    GtkTreeIter iter;
+    GNCImportTransInfo *trans_info;
+    gboolean multiple_accounts = FALSE;
+    gboolean valid;
+
+    g_assert (info);
+
+    model = gtk_tree_view_get_model (info->view);
+
+    if (gtk_tree_model_iter_n_children (model, NULL) > 1)
+    {
+        /* Get first row in list store */
+        valid = gtk_tree_model_get_iter_first (model, &iter);
+        if (valid)
+        {
+            gchar *account_name;
+            gtk_tree_model_get (model, &iter, DOWNLOADED_COL_ACCOUNT, &account_name, -1);
+
+            valid = gtk_tree_model_iter_next (model, &iter);
+
+            while (valid)
+            {
+                gchar *test_account_name;
+
+                gtk_tree_model_get (model, &iter, DOWNLOADED_COL_ACCOUNT, &test_account_name, -1);
+                if (g_strcmp0 (account_name, test_account_name) != 0)
+                {
+                     multiple_accounts = TRUE;
+                     g_free (test_account_name);
+                     break;
+                }
+                valid = gtk_tree_model_iter_next (model, &iter);
+                g_free (test_account_name);
+            }
+            g_free (account_name);
+        }
+        // now toggle the column
+        if (multiple_accounts)
+        {
+            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(info->show_account_column), TRUE);
+            gtk_tree_view_expand_all (info->view);
+        }
+        else
+        {
+            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(info->show_account_column), FALSE);
+            gtk_tree_view_collapse_all (info->view);
+        }
+    }
+}
+
 // This returns the transaction ID of the first match candidate in match_list
 static const GncGUID*
 get_top_trans_match_id (GList* match_list)
@@ -242,12 +298,12 @@ get_top_trans_match_id (GList* match_list)
     if (!match_list || !match_list->data) return NULL;
     match_info = match_list->data;
     trans = match_info->trans;
-    return xaccTransGetGUID(trans);
+    return xaccTransGetGUID (trans);
 }
 
 // This returns the transaction score of the first match candidate in match_list
 static gint
-get_top_trans_match_score(GList* match_list)
+get_top_trans_match_score (GList* match_list)
 {
     GNCImportMatchInfo* match_info;
     if (!match_list || !match_list->data) return 0;
@@ -266,7 +322,7 @@ get_trans_match_list (GtkTreeModel* model, GtkTreeIter* iter)
 }
 
 static GNCImportTransInfo*
-get_trans_info(GtkTreeModel* model, GtkTreeIter* iter)
+get_trans_info (GtkTreeModel* model, GtkTreeIter* iter)
 {
     GNCImportTransInfo* transaction_info;
     gtk_tree_model_get (model, iter,
@@ -337,7 +393,6 @@ static void
 resolve_conflicts (GNCImportMainMatcher *info)
 {
     GtkTreeModel* model = gtk_tree_view_get_model (info->view);
-    GtkListStore* store = GTK_LIST_STORE (model);
     GtkTreeIter import_iter, best_import;
     gint best_match = 0;
 
@@ -386,12 +441,14 @@ resolve_conflicts (GNCImportMainMatcher *info)
     }
 }
 
-void gnc_gen_trans_list_show_all(GNCImportMainMatcher *info)
+void
+gnc_gen_trans_list_show_all (GNCImportMainMatcher *info)
 {
     g_assert (info);
     gnc_gen_trans_list_create_matches (info);
     resolve_conflicts (info);
-    gtk_widget_show_all (GTK_WIDGET (info->main_widget));
+    gtk_widget_show_all (GTK_WIDGET(info->main_widget));
+    gnc_gen_trans_list_show_accounts_column (info);
 }
 
 void
@@ -415,7 +472,7 @@ on_matcher_ok_clicked (GtkButton *button, GNCImportMainMatcher *info)
 
     /* Don't run any queries and/or split sorts while processing the matcher
     results. */
-    gnc_suspend_gui_refresh();
+    gnc_suspend_gui_refresh ();
     do
     {
         gtk_tree_model_get (model, &iter,
@@ -435,11 +492,11 @@ on_matcher_ok_clicked (GtkButton *button, GNCImportMainMatcher *info)
         }
     }
     while (gtk_tree_model_iter_next (model, &iter));
-    
+
     gnc_gen_trans_list_delete (info);
 
     /* Allow GUI refresh again. */
-    gnc_resume_gui_refresh();
+    gnc_resume_gui_refresh ();
 
     /* DEBUG ("End") */
 }
@@ -476,7 +533,7 @@ on_matcher_help_clicked (GtkButton *button, gpointer user_data)
     gchar *int_required_class, *int_prob_required_class, *int_not_required_class;
     gchar *class_extension = NULL;
 
-    builder = gtk_builder_new();
+    builder = gtk_builder_new ();
     gnc_builder_add_from_file (builder, "dialog-import.glade", "textbuffer2");
     gnc_builder_add_from_file (builder, "dialog-import.glade", "textbuffer3");
     gnc_builder_add_from_file (builder, "dialog-import.glade", "textbuffer4");
@@ -527,7 +584,7 @@ run_account_picker_dialog (GNCImportMainMatcher *info,
     old_acc = gnc_import_TransInfo_get_destacc (trans_info);
 
     new_acc = gnc_import_select_account (
-            info->main_widget,
+             info->main_widget,
              NULL,
              TRUE,
              _("Destination account for the auto-balance split."),
@@ -650,13 +707,15 @@ gnc_gen_trans_assign_transfer_account (GtkTreeView *treeview,
     Account *old_acc;
     gboolean ok_pressed;
     gchar *path_str = gtk_tree_path_to_string (path);
+    gchar *acct_str = gnc_get_account_name_for_register (*new_acc);
 
     ENTER("");
     DEBUG("first = %s", *first ? "true" : "false");
     DEBUG("is_selection = %s", is_selection ? "true" : "false");
     DEBUG("path  = %s", path_str);
     g_free (path_str);
-    DEBUG("account passed in = %s", gnc_get_account_name_for_register (*new_acc));
+    DEBUG("account passed in = %s", acct_str);
+    g_free (acct_str);
 
     // only allow response at the top level
     if (gtk_tree_path_get_depth (path) != 1)
@@ -714,9 +773,8 @@ gnc_gen_trans_assign_transfer_account (GtkTreeView *treeview,
 }
 
 static void
-gnc_gen_trans_assign_transfer_account_to_selection_cb (
-            GtkMenuItem *menuitem,
-            GNCImportMainMatcher *info)
+gnc_gen_trans_assign_transfer_account_to_selection_cb (GtkMenuItem *menuitem,
+                                                       GNCImportMainMatcher *info)
 {
     GtkTreeView *treeview;
     GtkTreeSelection *selection;
@@ -748,16 +806,15 @@ gnc_gen_trans_assign_transfer_account_to_selection_cb (
             gchar *path_str = gtk_tree_path_to_string (l->data);
             GtkTreeRowReference *ref = gtk_tree_row_reference_new (model, l->data);
             DEBUG("passing first = %s", first ? "true" : "false");
-            DEBUG("passing is_selection = %s",
-                        is_selection ? "true" : "false");
+            DEBUG("passing is_selection = %s", is_selection ? "true" : "false");
             DEBUG("passing path = %s", path_str);
             g_free (path_str);
             refs = g_list_prepend (refs, ref);
             DEBUG("passing account value = %s",
                         gnc_account_get_full_name (assigned_account));
             gnc_gen_trans_assign_transfer_account (treeview,
-                        &first, is_selection, l->data,
-                        &assigned_account, info);
+                                                   &first, is_selection, l->data,
+                                                   &assigned_account, info);
             DEBUG("returned value of account = %s",
                         gnc_account_get_full_name (assigned_account));
             DEBUG("returned value of first = %s", first ? "true" : "false");
@@ -766,7 +823,7 @@ gnc_gen_trans_assign_transfer_account_to_selection_cb (
 
         }
     }
-    g_list_free_full (selected_rows, (GDestroyNotify) gtk_tree_path_free);
+    g_list_free_full (selected_rows, (GDestroyNotify)gtk_tree_path_free);
 
     // now reselect the transaction rows. This is very slow if there are lots of transactions.
     for (l = refs; l != NULL; l = l->next)
@@ -797,8 +854,8 @@ gnc_gen_trans_row_activated_cb (GtkTreeView *treeview,
     first = TRUE;
     is_selection = FALSE;
     gnc_gen_trans_assign_transfer_account (treeview,
-                            &first, is_selection, path,
-                            &assigned_account, info);
+                                           &first, is_selection, path,
+                                           &assigned_account, info);
 
     gtk_tree_selection_select_path (gtk_tree_view_get_selection (treeview), path);
 
@@ -835,9 +892,9 @@ gnc_gen_trans_row_changed_cb (GtkTreeSelection *selection,
             if (get_action_for_path (list->data, model) != GNCImport_ADD)
                 gtk_tree_selection_unselect_path (selection, list->data);
         }
-        g_list_free_full (list, (GDestroyNotify) gtk_tree_path_free);
+        g_list_free_full (list, (GDestroyNotify)gtk_tree_path_free);
     }
-    
+
     switch (mode)
     {
         case GTK_SELECTION_MULTIPLE:
@@ -871,7 +928,7 @@ gnc_gen_trans_view_popup_menu (GtkTreeView *treeview,
     ENTER ("");
     menu = gtk_menu_new();
     menuitem = gtk_menu_item_new_with_label (
-            _("Assign a transfer account to the selection."));
+                   _("Assign a transfer account to the selection."));
     g_signal_connect (menuitem, "activate",
                       G_CALLBACK(
                       gnc_gen_trans_assign_transfer_account_to_selection_cb),
@@ -918,7 +975,7 @@ gnc_gen_trans_onButtonPressed_cb (GtkTreeView *treeview,
                 get_action_for_path (selected->data, model);
                 if (get_action_for_path (selected->data, model) == GNCImport_ADD)
                     gnc_gen_trans_view_popup_menu (treeview, event, info);
-                g_list_free_full (selected, (GDestroyNotify) gtk_tree_path_free);
+                g_list_free_full (selected, (GDestroyNotify)gtk_tree_path_free);
             }
             LEAVE("return TRUE");
             return TRUE;
@@ -947,17 +1004,17 @@ gnc_gen_trans_onPopupMenu_cb (GtkTreeView *treeview,
 }
 
 static GtkTreeViewColumn *
-add_text_column(GtkTreeView *view, const gchar *title, int col_num, gboolean ellipsize)
+add_text_column (GtkTreeView *view, const gchar *title, int col_num, gboolean ellipsize)
 {
     GtkCellRenderer *renderer;
     GtkTreeViewColumn *column;
 
-    renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes
-             (title, renderer,
-              "text", col_num,
-              "background", DOWNLOADED_COL_COLOR,
-              NULL);
+    renderer = gtk_cell_renderer_text_new ();
+    column = gtk_tree_view_column_new_with_attributes (title,
+                                                       renderer,
+                                                       "text", col_num,
+                                                       "background", DOWNLOADED_COL_COLOR,
+                                                       NULL);
 
     if (ellipsize)
         g_object_set (renderer, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
@@ -989,18 +1046,15 @@ add_toggle_column (GtkTreeView *view, const gchar *title, int col_num,
     GtkCellRenderer *renderer;
     GtkTreeViewColumn *column;
 
-    renderer = gtk_cell_renderer_toggle_new();
-    column = gtk_tree_view_column_new_with_attributes
-             (title, renderer,
-              "active", col_num,
-              "cell-background", DOWNLOADED_COL_COLOR,
-              "activatable", DOWNLOADED_COL_ENABLE,
-              "visible", DOWNLOADED_COL_ENABLE,
-              NULL);
+    renderer = gtk_cell_renderer_toggle_new ();
+    column = gtk_tree_view_column_new_with_attributes (title, renderer,
+                                                       "active", col_num,
+                                                       "cell-background", DOWNLOADED_COL_COLOR,
+                                                       "activatable", DOWNLOADED_COL_ENABLE,
+                                                       "visible", DOWNLOADED_COL_ENABLE,
+                                                       NULL);
     gtk_tree_view_column_set_sort_column_id (column, col_num);
-    g_object_set (G_OBJECT(column),
-                  "reorderable", TRUE,
-                  NULL);
+    g_object_set (G_OBJECT(column), "reorderable", TRUE, NULL);
     g_signal_connect (renderer, "toggled", cb_fn, cb_arg);
     gtk_tree_view_append_column (view, column);
     return column;
@@ -1036,25 +1090,25 @@ gnc_gen_trans_init_view (GNCImportMainMatcher *info,
     gtk_tree_view_column_set_visible (info->account_column, show_account);
     add_text_column (view, _("Amount"), DOWNLOADED_COL_AMOUNT, FALSE);
     add_text_column (view, _("Description"), DOWNLOADED_COL_DESCRIPTION, FALSE);
-    add_text_column (view, _("Memo"), DOWNLOADED_COL_MEMO, TRUE);
-    add_toggle_column (view,
-                       C_("Column header for 'Adding transaction'", "A"), DOWNLOADED_COL_ACTION_ADD,
+    info->memo_column = add_text_column (view, _("Memo"), DOWNLOADED_COL_MEMO, TRUE);
+    add_toggle_column (view, C_("Column header for 'Adding transaction'", "A"),
+                       DOWNLOADED_COL_ACTION_ADD,
                        G_CALLBACK(gnc_gen_trans_add_toggled_cb), info);
-    column = add_toggle_column (view,
-                               C_("Column header for 'Updating plus Clearing transaction'", "U+C"), DOWNLOADED_COL_ACTION_UPDATE,
-                               G_CALLBACK(gnc_gen_trans_update_toggled_cb), info);
+    column = add_toggle_column (view, C_("Column header for 'Updating plus Clearing transaction'", "U+C"),
+                                DOWNLOADED_COL_ACTION_UPDATE,
+                                G_CALLBACK(gnc_gen_trans_update_toggled_cb), info);
     gtk_tree_view_column_set_visible (column, show_update);
-    add_toggle_column (view,
-                       C_("Column header for 'Clearing transaction'", "C"), DOWNLOADED_COL_ACTION_CLEAR,
-                      G_CALLBACK(gnc_gen_trans_clear_toggled_cb), info);
+    add_toggle_column (view, C_("Column header for 'Clearing transaction'", "C"),
+                       DOWNLOADED_COL_ACTION_CLEAR,
+                       G_CALLBACK(gnc_gen_trans_clear_toggled_cb), info);
 
     /* The last column has multiple renderers */
-    renderer = gtk_cell_renderer_pixbuf_new();
+    renderer = gtk_cell_renderer_pixbuf_new ();
     g_object_set (renderer, "xalign", 0.0, NULL);
     column = gtk_tree_view_column_new_with_attributes (_("Info"), renderer,
-             "pixbuf", DOWNLOADED_COL_ACTION_PIXBUF,
-             "cell-background", DOWNLOADED_COL_COLOR,
-             NULL);
+                                                       "pixbuf", DOWNLOADED_COL_ACTION_PIXBUF,
+                                                       "cell-background", DOWNLOADED_COL_COLOR,
+                                                       NULL);
 
     gtk_tree_view_append_column (info->view, column);
 
@@ -1067,16 +1121,19 @@ gnc_gen_trans_init_view (GNCImportMainMatcher *info,
                                           GTK_SORT_ASCENDING);
     selection = gtk_tree_view_get_selection (info->view);
 
+    g_object_set (info->view, "has-tooltip", TRUE, NULL);
+
+    g_signal_connect (G_OBJECT(info->view), "query-tooltip",
+                      G_CALLBACK(query_tooltip_tree_view_cb), info);
     g_signal_connect (info->view, "row-activated",
                       G_CALLBACK(gnc_gen_trans_row_activated_cb), info);
     g_signal_connect (selection, "changed",
                       G_CALLBACK(gnc_gen_trans_row_changed_cb), info);
-
     g_signal_connect (view, "button-press-event",
                       G_CALLBACK(gnc_gen_trans_onButtonPressed_cb), info);
     g_signal_connect (view, "popup-menu",
                       G_CALLBACK(gnc_gen_trans_onPopupMenu_cb), info);
-    
+
     info->acct_id_hash = g_hash_table_new (g_direct_hash, g_direct_equal);
 }
 
@@ -1088,9 +1145,17 @@ show_account_column_toggled_cb (GtkToggleButton *togglebutton,
         gtk_toggle_button_get_active (togglebutton));
 }
 
+static void
+show_memo_column_toggled_cb (GtkToggleButton *togglebutton,
+                             GNCImportMainMatcher *info)
+{
+    gtk_tree_view_column_set_visible (info->memo_column,
+        gtk_toggle_button_get_active (togglebutton));
+}
+
 static void
 show_matched_info_toggled_cb (GtkToggleButton *togglebutton,
-                                GNCImportMainMatcher *info)
+                              GNCImportMainMatcher *info)
 {
     if (gtk_toggle_button_get_active (togglebutton))
     {
@@ -1105,23 +1170,20 @@ show_matched_info_toggled_cb (GtkToggleButton *togglebutton,
     }
 }
 
-GNCImportMainMatcher *gnc_gen_trans_list_new (GtkWidget *parent,
-        const gchar* heading,
-        gboolean all_from_same_account,
-        gint match_date_hardlimit,
-        gboolean show_all)
+static void
+gnc_gen_trans_common_setup (GNCImportMainMatcher *info,
+                            GtkWidget *parent,
+                            GtkBuilder *builder,
+                            const gchar* heading,
+                            gboolean all_from_same_account,
+                            gint match_date_hardlimit)
 {
-    GNCImportMainMatcher *info;
-    GtkBuilder *builder;
-    GtkWidget *heading_label;
-    GtkWidget *box, *pbox;
-    gboolean show_update;
     GtkStyleContext *stylectxt;
     GdkRGBA color;
-    GtkWidget *button;
+    GtkWidget *heading_label, *button;
+    gboolean show_update;
 
-    info = g_new0 (GNCImportMainMatcher, 1);
-    info->pending_matches = gnc_import_PendingMatches_new();
+    info->pending_matches = gnc_import_PendingMatches_new ();
 
     /* Initialize user Settings. */
     info->user_settings = gnc_import_Settings_new ();
@@ -1131,18 +1193,6 @@ GNCImportMainMatcher *gnc_gen_trans_list_new (GtkWidget *parent,
     gtk_style_context_get_color (stylectxt, GTK_STATE_FLAG_NORMAL, &color);
     info->dark_theme = gnc_is_dark_theme (&color);
 
-    /* Initialize the GtkDialog. */
-    builder = gtk_builder_new();
-    gnc_builder_add_from_file (builder, "dialog-import.glade", "transaction_matcher_dialog");
-    gnc_builder_add_from_file (builder, "dialog-import.glade", "transaction_matcher_content");
-    info->main_widget = GTK_WIDGET(gtk_builder_get_object (builder, "transaction_matcher_dialog"));
-    g_assert (info->main_widget != NULL);
-
-    /* Pack the content into the dialog vbox */
-    pbox = GTK_WIDGET(gtk_builder_get_object (builder, "transaction_matcher_vbox"));
-    box = GTK_WIDGET(gtk_builder_get_object (builder, "transaction_matcher_content"));
-    gtk_box_pack_start (GTK_BOX(pbox), box, TRUE, TRUE, 0);
-
     /* Get the view */
     info->view = GTK_TREE_VIEW(gtk_builder_get_object (builder, "downloaded_view"));
     g_assert (info->view != NULL);
@@ -1152,6 +1202,11 @@ GNCImportMainMatcher *gnc_gen_trans_list_new (GtkWidget *parent,
     g_signal_connect (G_OBJECT(info->show_account_column), "toggled",
                       G_CALLBACK(show_account_column_toggled_cb), info);
 
+    button = GTK_WIDGET(gtk_builder_get_object (builder, "show_memo_column_button"));
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(button), TRUE);
+    g_signal_connect (G_OBJECT(button), "toggled",
+                      G_CALLBACK(show_memo_column_toggled_cb), info);
+
     info->show_matched_info = GTK_WIDGET(gtk_builder_get_object (builder, "show_matched_info_button"));
     g_signal_connect (G_OBJECT(info->show_matched_info), "toggled",
                       G_CALLBACK(show_matched_info_toggled_cb), info);
@@ -1164,15 +1219,8 @@ GNCImportMainMatcher *gnc_gen_trans_list_new (GtkWidget *parent,
     heading_label = GTK_WIDGET(gtk_builder_get_object (builder, "heading_label"));
     g_assert (heading_label != NULL);
 
-    if (parent)
-        gtk_window_set_transient_for (GTK_WINDOW (info->main_widget), GTK_WINDOW (parent));
-
     if (heading)
-        gtk_label_set_text (GTK_LABEL (heading_label), heading);
-
-    gnc_restore_window_size (GNC_PREFS_GROUP, GTK_WINDOW(info->main_widget), GTK_WINDOW (parent));
-    if(show_all)
-        gtk_widget_show_all (GTK_WIDGET (info->main_widget));
+        gtk_label_set_text (GTK_LABEL(heading_label), heading);
 
     info->transaction_processed_cb = NULL;
 
@@ -1180,6 +1228,46 @@ GNCImportMainMatcher *gnc_gen_trans_list_new (GtkWidget *parent,
     gtk_builder_connect_signals_full (builder, gnc_builder_connect_full_func, info);
 
     g_object_unref (G_OBJECT(builder));
+}
+
+
+GNCImportMainMatcher *
+gnc_gen_trans_list_new (GtkWidget *parent,
+                        const gchar* heading,
+                        gboolean all_from_same_account,
+                        gint match_date_hardlimit,
+                        gboolean show_all)
+{
+    GNCImportMainMatcher *info;
+    GtkBuilder *builder;
+    GtkWidget *box, *pbox;
+
+    info = g_new0 (GNCImportMainMatcher, 1);
+
+    /* Initialize the GtkDialog. */
+    builder = gtk_builder_new ();
+    gnc_builder_add_from_file (builder, "dialog-import.glade", "transaction_matcher_dialog");
+    gnc_builder_add_from_file (builder, "dialog-import.glade", "transaction_matcher_content");
+
+    info->main_widget = GTK_WIDGET(gtk_builder_get_object (builder, "transaction_matcher_dialog"));
+    g_assert (info->main_widget != NULL);
+
+    /* Pack the content into the dialog vbox */
+    pbox = GTK_WIDGET(gtk_builder_get_object (builder, "transaction_matcher_vbox"));
+    box = GTK_WIDGET(gtk_builder_get_object (builder, "transaction_matcher_content"));
+    gtk_box_pack_start (GTK_BOX(pbox), box, TRUE, TRUE, 0);
+
+    /* setup the common parts */
+    gnc_gen_trans_common_setup (info, parent, builder, heading,
+                                all_from_same_account, match_date_hardlimit);
+
+    if (parent)
+        gtk_window_set_transient_for (GTK_WINDOW(info->main_widget), GTK_WINDOW(parent));
+
+    gnc_restore_window_size (GNC_PREFS_GROUP, GTK_WINDOW(info->main_widget), GTK_WINDOW(parent));
+
+    if (show_all)
+        gtk_widget_show_all (GTK_WIDGET(info->main_widget));
 
     // Register this UI, it needs to be closed when the session is closed.
     info->id = gnc_register_gui_component (IMPORT_MAIN_MATCHER_CM_CLASS,
@@ -1195,76 +1283,38 @@ GNCImportMainMatcher *gnc_gen_trans_list_new (GtkWidget *parent,
  *                 Assistant routines Start                      *
  *****************************************************************/
 
-GNCImportMainMatcher * gnc_gen_trans_assist_new (GtkWidget *parent,
-        GtkWidget *assistant_page, const gchar* heading,
-        gboolean all_from_same_account, gint match_date_hardlimit)
+GNCImportMainMatcher *
+gnc_gen_trans_assist_new (GtkWidget *parent,
+                          GtkWidget *assistant_page,
+                          const gchar* heading,
+                          gboolean all_from_same_account,
+                          gint match_date_hardlimit)
 {
     GNCImportMainMatcher *info;
     GtkBuilder *builder;
-    GtkWidget *heading_label;
     GtkWidget *box;
-    gboolean show_update;
-    GtkStyleContext *stylectxt;
-    GdkRGBA color;
 
     info = g_new0 (GNCImportMainMatcher, 1);
-    info->pending_matches = gnc_import_PendingMatches_new();
     info->main_widget = GTK_WIDGET(parent);
 
-    /* Initialize user Settings. */
-    info->user_settings = gnc_import_Settings_new ();
-    gnc_import_Settings_set_match_date_hardlimit (info->user_settings, match_date_hardlimit);
-
-    stylectxt = gtk_widget_get_style_context (GTK_WIDGET(parent));
-    gtk_style_context_get_color (stylectxt, GTK_STATE_FLAG_NORMAL, &color);
-    info->dark_theme = gnc_is_dark_theme (&color);
-
     /* load the interface */
-    builder = gtk_builder_new();
+    builder = gtk_builder_new ();
     gnc_builder_add_from_file (builder, "dialog-import.glade", "transaction_matcher_content");
-    if (builder == NULL)
-    {
-        PERR("Error opening the glade builder interface");
-    }
+
     /* Pack content into Assistant page widget */
     box = GTK_WIDGET(gtk_builder_get_object (builder, "transaction_matcher_content"));
+    g_assert (box != NULL);
     gtk_box_pack_start (GTK_BOX(assistant_page), box, TRUE, TRUE, 6);
 
-    /* Get the view */
-    info->view = GTK_TREE_VIEW(gtk_builder_get_object (builder, "downloaded_view"));
-    g_assert (info->view != NULL);
-
-    info->show_account_column = GTK_WIDGET(gtk_builder_get_object (builder, "show_source_account_button"));
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(info->show_account_column), all_from_same_account);
-    g_signal_connect (G_OBJECT(info->show_account_column), "toggled",
-                      G_CALLBACK(show_account_column_toggled_cb), info);
-
-    info->show_matched_info = GTK_WIDGET(gtk_builder_get_object (builder, "show_matched_info_button"));
-    g_signal_connect (G_OBJECT(info->show_matched_info), "toggled",
-                      G_CALLBACK(show_matched_info_toggled_cb), info);
-
-    // Create the checkbox, but do not show it by default.
-    info->reconcile_after_close = GTK_WIDGET(gtk_builder_get_object (builder, "reconcile_after_close_button"));
-
-    show_update = gnc_import_Settings_get_action_update_enabled (info->user_settings);
-    gnc_gen_trans_init_view (info, all_from_same_account, show_update);
-    heading_label = GTK_WIDGET(gtk_builder_get_object (builder, "heading_label"));
-    g_assert (heading_label != NULL);
-
-    if (heading)
-        gtk_label_set_text (GTK_LABEL (heading_label), heading);
-
-    info->transaction_processed_cb = NULL;
-
-    /* Connect the signals */
-    gtk_builder_connect_signals_full (builder, gnc_builder_connect_full_func, info);
-
-    g_object_unref (G_OBJECT(builder));
+    /* setup the common parts */
+    gnc_gen_trans_common_setup (info, parent, builder, heading,
+                                all_from_same_account, match_date_hardlimit);
 
     return info;
 }
 
-void gnc_gen_trans_assist_start (GNCImportMainMatcher *info)
+void
+gnc_gen_trans_assist_start (GNCImportMainMatcher *info)
 {
     on_matcher_ok_clicked (NULL, info);
 }
@@ -1273,15 +1323,17 @@ void gnc_gen_trans_assist_start (GNCImportMainMatcher *info)
  *                   Assistant routines End                      *
  *****************************************************************/
 
-void gnc_gen_trans_list_add_tp_cb (GNCImportMainMatcher *info,
-                                   GNCTransactionProcessedCB trans_processed_cb,
-                                   gpointer user_data)
+void
+gnc_gen_trans_list_add_tp_cb (GNCImportMainMatcher *info,
+                              GNCTransactionProcessedCB trans_processed_cb,
+                              gpointer user_data)
 {
     info->user_data = user_data;
     info->transaction_processed_cb = trans_processed_cb;
 }
 
-gboolean gnc_gen_trans_list_run (GNCImportMainMatcher *info)
+gboolean
+gnc_gen_trans_list_run (GNCImportMainMatcher *info)
 {
     gboolean result;
 
@@ -1337,7 +1389,7 @@ update_child_row (GNCImportMatchInfo *sel_match, GtkTreeModel *model, GtkTreeIte
 
     gtk_tree_store_set (store, &child, DOWNLOADED_COL_DATE_TXT, text, -1);
 
-    if (xaccTransCountSplits(sel_match->trans) == 2)
+    if (xaccTransCountSplits (sel_match->trans) == 2)
         gtk_tree_store_set (store, &child, DOWNLOADED_COL_ACCOUNT, xaccAccountGetName (
                             xaccSplitGetAccount (xaccSplitGetOtherSplit (sel_match->split))), -1);
     else
@@ -1610,6 +1662,7 @@ refresh_model_row (GNCImportMainMatcher *gui,
             GtkTreePath *path = gtk_tree_model_get_path (model, iter);
 
             gtk_tree_view_column_set_visible (gui->account_column, TRUE);
+            gtk_tree_view_column_set_visible (gui->memo_column, TRUE);
 
             gtk_tree_view_expand_row (GTK_TREE_VIEW(gui->view), path, TRUE);
             gtk_tree_path_free (path);
@@ -1619,16 +1672,17 @@ refresh_model_row (GNCImportMainMatcher *gui,
     gtk_tree_selection_unselect_all (selection);
 }
 
-void gnc_gen_trans_list_add_trans (GNCImportMainMatcher *gui, Transaction *trans)
+void
+gnc_gen_trans_list_add_trans (GNCImportMainMatcher *gui, Transaction *trans)
 {
     Account* acc = NULL;
     Split* split = NULL;
     int i=0;
-    
+
     split = xaccTransGetSplit (trans, 0);
     acc = xaccSplitGetAccount (split);
     defer_bal_computation (gui, acc);
-    
+
     gnc_gen_trans_list_add_trans_with_ref_id (gui, trans, 0);
     return;
 }/* end gnc_import_add_trans() */
@@ -1648,14 +1702,15 @@ gnc_gen_trans_list_get_reconcile_after_close_button (GNCImportMainMatcher *info)
     return info->reconcile_after_close;
 }
 
-void gnc_gen_trans_list_add_trans_with_ref_id (GNCImportMainMatcher *gui, Transaction *trans, guint32 ref_id)
+void
+gnc_gen_trans_list_add_trans_with_ref_id (GNCImportMainMatcher *gui, Transaction *trans, guint32 ref_id)
 {
     GNCImportTransInfo * transaction_info = NULL;
     GtkTreeModel *model;
     GtkTreeIter iter;
     g_assert (gui);
     g_assert (trans);
-  
+
     if (gnc_import_exists_online_id (trans, gui->acct_id_hash))
         return;
     else
@@ -1669,7 +1724,6 @@ void gnc_gen_trans_list_add_trans_with_ref_id (GNCImportMainMatcher *gui, Transa
     return;
 }
 
-
 /* Query the accounts used by the imported transactions to find a list of
  * candidate matching transactions.
  */
@@ -1698,12 +1752,12 @@ query_imported_transaction_accounts (GNCImportMainMatcher *gui)
         time64 txn_time =
             xaccTransGetDate (gnc_import_TransInfo_get_trans (txn_info));
         all_accounts = g_list_prepend (all_accounts, txn_account);
-        min_time = MIN (min_time, txn_time);
-        max_time = MAX (max_time, txn_time);
+        min_time = MIN(min_time, txn_time);
+        max_time = MAX(max_time, txn_time);
     }
 
     // Make a query to find splits with the right accounts and dates.
-    qof_query_set_book (query, gnc_get_current_book());
+    qof_query_set_book (query, gnc_get_current_book ());
     xaccQueryAddAccountMatch (query, all_accounts,
                               QOF_GUID_MATCH_ANY, QOF_QUERY_AND);
     xaccQueryAddDateMatchTT (query,
@@ -1806,7 +1860,7 @@ void
 gnc_gen_trans_list_create_matches (GNCImportMainMatcher *gui)
 {
     GHashTable* account_hash =
-        g_hash_table_new_full(g_direct_hash, g_direct_equal, NULL,
+        g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL,
                               (GDestroyNotify)g_slist_free);
     GList *candidate_txns;
     g_assert (gui);
@@ -1820,10 +1874,61 @@ gnc_gen_trans_list_create_matches (GNCImportMainMatcher *gui)
     return;
 }
 
-GtkWidget *gnc_gen_trans_list_widget (GNCImportMainMatcher *info)
+GtkWidget *
+gnc_gen_trans_list_widget (GNCImportMainMatcher *info)
 {
     g_assert (info);
     return info->main_widget;
 }
 
+gboolean
+query_tooltip_tree_view_cb (GtkWidget *widget, gint x, gint y,
+                            gboolean keyboard_tip,
+                            GtkTooltip *tooltip,
+                            gpointer user_data)
+{
+    GtkTreeView          *tree_view = GTK_TREE_VIEW(widget);
+    GtkTreeModel         *model = gtk_tree_view_get_model (tree_view);
+    GtkTreePath          *path  = NULL;
+    GtkTreeViewColumn    *column = NULL;
+    GtkTreeIter iter;
+    gboolean show_tooltip = FALSE;
+
+    gtk_tree_view_convert_widget_to_bin_window_coords (tree_view, x, y, &x, &y);
+    if (keyboard_tip || !gtk_tree_view_get_path_at_pos (tree_view, x, y, &path,
+                                                        &column, NULL, NULL))
+        return FALSE;
+
+    // Get the iter pointing to our current column
+    if (gtk_tree_model_get_iter(model, &iter, path) && column)
+    {
+        const gchar *tooltip_text = NULL;
+
+        // Select text based on column
+        gint num_col = gtk_tree_view_column_get_sort_column_id (column);
+        switch (num_col)
+        {
+        case DOWNLOADED_COL_DESCRIPTION:
+            gtk_tree_model_get (model, &iter, DOWNLOADED_COL_DESCRIPTION, &tooltip_text, -1);
+            break;
+        case DOWNLOADED_COL_MEMO:
+            gtk_tree_model_get (model, &iter, DOWNLOADED_COL_MEMO, &tooltip_text, -1);
+            break;
+        default:
+            break;
+        }
+
+        // Did we select any text? If yes, display the tooltip
+        if (tooltip_text && *tooltip_text)
+        {
+            show_tooltip = TRUE;
+            gtk_tooltip_set_text (tooltip, tooltip_text);
+            gtk_tree_view_set_tooltip_cell (tree_view, tooltip, path, column, NULL);
+        }
+    }
+    // Clean up the object
+    gtk_tree_path_free (path);
+    return show_tooltip;
+}
+
 /** @} */
