@@ -27,14 +27,14 @@
 
 #include "datecell.h"
 #include "dialog-utils.h"
-#include "dialog-assoc-utils.h"
+#include "dialog-doclink-utils.h"
 #include "gnc-engine.h"
 #include "gnc-prefs.h"
 #include "gnc-ui.h"
 #include "gnc-uri-utils.h"
 #include "gnc-filepath-utils.h"
 #include "gnc-warnings.h"
-#include "assoccell.h"
+#include "doclinkcell.h"
 #include "pricecell.h"
 #include "recncell.h"
 #include "split-register.h"
@@ -328,10 +328,10 @@ gnc_split_register_get_action_label (VirtualLocation virt_loc,
 }
 
 static const char*
-gnc_split_register_get_associate_label (VirtualLocation virt_loc,
-                                        gpointer user_data)
+gnc_split_register_get_doclink_label (VirtualLocation virt_loc,
+                                      gpointer user_data)
 {
-    return C_ ("Column header for 'Associate'", "A");
+    return C_ ("Column header for 'Document Link'", "L");
 }
 
 static const char*
@@ -545,8 +545,8 @@ gnc_split_register_get_recn_tooltip (VirtualLocation virt_loc,
 }
 
 static char*
-gnc_split_register_get_associate_tooltip (VirtualLocation virt_loc,
-                                          gpointer user_data)
+gnc_split_register_get_doclink_tooltip (VirtualLocation virt_loc,
+                                        gpointer user_data)
 {
     SplitRegister* reg = user_data;
     Transaction* trans;
@@ -557,11 +557,11 @@ gnc_split_register_get_associate_tooltip (VirtualLocation virt_loc,
         return NULL;
 
     // get the existing uri
-    uri = xaccTransGetAssociation (trans);
+    uri = xaccTransGetDocLink (trans);
 
     // Check for uri is empty or NULL
     if (uri && *uri)
-        return gnc_assoc_get_unescaped_just_uri (uri);
+        return gnc_doclink_get_unescaped_just_uri (uri);
     else
         return NULL;
 }
@@ -797,18 +797,18 @@ gnc_split_register_get_border (VirtualLocation virt_loc,
 }
 
 static const char*
-gnc_split_register_get_associate_entry (VirtualLocation virt_loc,
-                                        gboolean translate,
-                                        gboolean* conditionally_changed,
-                                        gpointer user_data)
+gnc_split_register_get_doclink_entry (VirtualLocation virt_loc,
+                                      gboolean translate,
+                                      gboolean* conditionally_changed,
+                                      gpointer user_data)
 {
     SplitRegister* reg = user_data;
     Transaction* trans;
-    char associate;
+    char link_flag;
     const char* uri;
-    AssocCell *cell;
+    Doclinkcell *cell;
 
-    cell = (AssocCell *)gnc_table_layout_get_cell (reg->table->layout, ASSOC_CELL);
+    cell = (Doclinkcell *)gnc_table_layout_get_cell (reg->table->layout, DOCLINK_CELL);
 
     if (!cell)
         return NULL;
@@ -818,7 +818,7 @@ gnc_split_register_get_associate_entry (VirtualLocation virt_loc,
         return NULL;
 
     // get the existing uri
-    uri = xaccTransGetAssociation (trans);
+    uri = xaccTransGetDocLink (trans);
 
     // Check for uri is empty or NULL
     if (uri && *uri)
@@ -826,33 +826,33 @@ gnc_split_register_get_associate_entry (VirtualLocation virt_loc,
         gchar* scheme = gnc_uri_get_scheme (uri);
 
         if (!scheme || g_strcmp0 (scheme, "file") == 0)
-            associate = FASSOC;
+            link_flag = FLINK;
         else
-            associate = WASSOC;
+            link_flag = WLINK;
 
         g_free (scheme);
     }
     else
-        associate = ' ';
+        link_flag = ' ';
 
-    if (gnc_assoc_get_use_glyphs (cell))
-        return gnc_assoc_get_glyph_from_flag (associate);
+    if (gnc_doclink_get_use_glyphs (cell))
+        return gnc_doclink_get_glyph_from_flag (link_flag);
 
     if (translate)
-        return gnc_get_association_str (associate);
+        return gnc_get_doclink_str (link_flag);
     else
     {
         static char s[2];
 
-        s[0] = associate;
+        s[0] = link_flag;
         s[1] = '\0';
         return s;
     }
 }
 
 static char *
-gnc_split_register_get_associate_help (VirtualLocation virt_loc,
-                                       gpointer user_data)
+gnc_split_register_get_doclink_help (VirtualLocation virt_loc,
+                                     gpointer user_data)
 {
     // do not want contents displayed as help so return space
     return g_strdup (" ");
@@ -861,16 +861,16 @@ gnc_split_register_get_associate_help (VirtualLocation virt_loc,
 #if 0
 // this code is not used yet
 static char
-gnc_split_register_get_associate_value (SplitRegister* reg,
-                                        VirtualLocation virt_loc)
+gnc_split_register_get_doclink_value (SplitRegister* reg,
+                                      VirtualLocation virt_loc)
 {
-    AssocCell *cell;
+    Doclinkcell *cell;
 
-    cell = (AssocCell *)gnc_table_layout_get_cell (reg->table->layout, ASSOC_CELL);
+    cell = (Doclinkcell *)gnc_table_layout_get_cell (reg->table->layout, DOCLINK_CELL);
     if (!cell)
         return '\0';
 
-    return gnc_assoc_cell_get_flag (cell);
+    return gnc_doclink_cell_get_flag (cell);
 }
 #endif
 
@@ -2015,8 +2015,8 @@ gnc_split_register_get_recn_io_flags (VirtualLocation virt_loc,
 }
 
 static CellIOFlags
-gnc_split_register_get_assoc_io_flags (VirtualLocation virt_loc,
-                                       gpointer user_data)
+gnc_split_register_get_doclink_io_flags (VirtualLocation virt_loc,
+                                         gpointer user_data)
 {
     if (gnc_split_register_cursor_is_readonly (virt_loc, user_data))
         return XACC_CELL_ALLOW_READ_ONLY;
@@ -2215,7 +2215,7 @@ gnc_split_register_confirm (VirtualLocation virt_loc, gpointer user_data)
         title = _ ("Change transaction containing a reconciled split?");
         message_format =
             _ ("The transaction you are about to change contains reconciled splits in the following accounts:\n%s"
-               "\n\nAre you sure you want to continue with this change ?");
+               "\n\nAre you sure you want to continue with this change?");
 
         message = g_strdup_printf (message_format, acc_list);
         g_free (acc_list);
@@ -2582,8 +2582,8 @@ gnc_split_register_model_new (void)
                                        TCRED_CELL);
 
     gnc_table_model_set_entry_handler (model,
-                                       gnc_split_register_get_associate_entry,
-                                       ASSOC_CELL);
+                                       gnc_split_register_get_doclink_entry,
+                                       DOCLINK_CELL);
 
     gnc_table_model_set_entry_handler (model,
                                        gnc_split_register_get_type_entry,
@@ -2683,8 +2683,8 @@ gnc_split_register_model_new (void)
                                        TBALN_CELL);
 
     gnc_table_model_set_label_handler (model,
-                                       gnc_split_register_get_associate_label,
-                                       ASSOC_CELL);
+                                       gnc_split_register_get_doclink_label,
+                                       DOCLINK_CELL);
 
     gnc_table_model_set_label_handler (model,
                                        gnc_split_register_get_type_label,
@@ -2715,8 +2715,8 @@ gnc_split_register_model_new (void)
                                          RECN_CELL);
 
     gnc_table_model_set_tooltip_handler (model,
-                                         gnc_split_register_get_associate_tooltip,
-                                         ASSOC_CELL);
+                                         gnc_split_register_get_doclink_tooltip,
+                                         DOCLINK_CELL);
 
 
     // help handlers
@@ -2784,8 +2784,8 @@ gnc_split_register_model_new (void)
                                       FDEBT_CELL);
 
     gnc_table_model_set_help_handler (model,
-                                      gnc_split_register_get_associate_help,
-                                      ASSOC_CELL);
+                                      gnc_split_register_get_doclink_help,
+                                      DOCLINK_CELL);
 
     // io flag handlers
     gnc_table_model_set_io_flags_handler (
@@ -2839,7 +2839,7 @@ gnc_split_register_model_new (void)
         model, gnc_split_register_get_recn_io_flags, RECN_CELL);
 
     gnc_table_model_set_io_flags_handler (
-        model, gnc_split_register_get_assoc_io_flags, ASSOC_CELL);
+        model, gnc_split_register_get_doclink_io_flags, DOCLINK_CELL);
 
     gnc_table_model_set_io_flags_handler (
         model, gnc_split_register_get_recn_io_flags, TYPE_CELL);
