@@ -536,7 +536,8 @@ gnc_combo_cell_type_ahead_search (const gchar* newval,
     GRegex* regex0 = g_regex_new (escaped_sep, 0, 0, NULL);
     char* rep_str = g_regex_replace_literal (regex0, escaped_newval, -1, 0,
                                              newval_rep, 0, NULL);
-    GRegex *regex = g_regex_new (rep_str, G_REGEX_CASELESS, 0, NULL);
+    char* normal_rep_str = g_utf8_normalize (rep_str, -1, G_NORMALIZE_ALL);
+    GRegex *regex = g_regex_new (normal_rep_str, G_REGEX_CASELESS, 0, NULL);
 
     gboolean valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (full_store),
                                                     &iter);
@@ -546,6 +547,7 @@ gnc_combo_cell_type_ahead_search (const gchar* newval,
      */
     static const gint MAX_NUM_MATCHES = 30;
 
+    g_free (normal_rep_str);
     g_free (rep_str);
     g_free (newval_rep);
     g_free (escaped_sep);
@@ -914,7 +916,9 @@ popup_get_height (G_GNUC_UNUSED GtkWidget* widget,
     {
         gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin),
                                         GTK_POLICY_AUTOMATIC, GTK_POLICY_NEVER);
-        return height;
+        // if the list is empty height would be 0 so return 1 instead to
+        // satisfy the check_popup_height_is_true function
+        return height ? height : 1;
     }
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin),
                                     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -971,6 +975,7 @@ gnc_combo_cell_enter (BasicCell* bcell,
 {
     ComboCell* cell = (ComboCell*) bcell;
     PopBox* box = bcell->gui_private;
+    PopupToggle popup_toggle;
     GList* find = NULL;
 
     if (bcell->value)
@@ -997,6 +1002,12 @@ gnc_combo_cell_enter (BasicCell* bcell,
     gnc_item_list_select (box->item_list, bcell->value);
     unblock_list_signals (cell);
 
+    popup_toggle = box->item_edit->popup_toggle;
+
+    // if the list is empty disable the toggle button
+    gtk_widget_set_sensitive (GTK_WIDGET(popup_toggle.tbutton),
+                              gnc_item_list_num_entries (box->item_list));
+
     combo_connect_signals (cell);
 
     *cursor_position = -1;
