@@ -32,6 +32,7 @@
 
 #include <config.h>
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <glib-object.h>
 #include <stdlib.h>
 
@@ -52,6 +53,7 @@
 
 #undef G_LOG_DOMAIN
 #define G_LOG_DOMAIN "gnc.app-utils.sx"
+static QofLogModule log_module = G_LOG_DOMAIN;
 
 /** Report errors bilingual:
  *  in g_critical untranslated and
@@ -266,6 +268,7 @@ _get_vars_helper(Transaction *txn, void *var_hash_data)
 			  "sx-debit-formula", &debit_formula,
 			  NULL);
         acct = xaccAccountLookup(acct_guid, gnc_get_current_book());
+        guid_free (acct_guid);
         split_cmdty = xaccAccountGetCommodity(acct);
         // existing... ------------------------------------------
 	if (credit_formula && strlen(credit_formula) != 0)
@@ -519,9 +522,10 @@ gnc_sx_get_instances(const GDate *range_end, gboolean include_disabled)
             SchedXaction *sx = (SchedXaction*)sx_iter->data;
             if (xaccSchedXactionGetEnabled(sx))
             {
-                enabled_sxes = g_list_append(enabled_sxes, sx);
+                enabled_sxes = g_list_prepend (enabled_sxes, sx);
             }
         }
+        enabled_sxes = g_list_reverse (enabled_sxes);
         instances->sx_instance_list = gnc_g_list_map(enabled_sxes, (GncGMapFunc)_gnc_sx_gen_instances, (gpointer)range_end);
         g_list_free(enabled_sxes);
     }
@@ -974,6 +978,7 @@ _get_template_split_account(const SchedXaction* sx,
 			    Account **split_acct,
 			    GList **creation_errors)
 {
+    gboolean success = TRUE;
     GncGUID *acct_guid = NULL;
     qof_instance_get (QOF_INSTANCE (template_split),
 		      "sx-account", &acct_guid,
@@ -983,14 +988,15 @@ _get_template_split_account(const SchedXaction* sx,
     {
         char guid_str[GUID_ENCODING_LENGTH+1];
 /* Translators: A list of error messages from the Scheduled Transactions (SX).
- * They might appear in their editor or in "Since last run".                  */
+   They might appear in their editor or in "Since last run".                  */
         gchar* err = N_("Unknown account for guid [%s], cancelling SX [%s] creation.");
         guid_to_string_buff((const GncGUID*)acct_guid, guid_str);
         REPORT_ERROR(creation_errors, err, guid_str, xaccSchedXactionGetName(sx));
-        return FALSE;
+        success = FALSE;
     }
 
-    return TRUE;
+    guid_free (acct_guid);
+    return success;
 }
 
 static void
@@ -1149,7 +1155,7 @@ split_apply_exchange_rate (Split *split, GHashTable *bindings,
  * the template_transaction's commodity.
  *
  * Since we're going through the split commodities anyway, check that they all
- * have useable values. If we find an error return NULL as a signal to
+ * have usable values. If we find an error return NULL as a signal to
  * create_each_transaction_helper to bail out.
  */
 
