@@ -30,27 +30,13 @@ extern "C"
 #include "config.h"
 
 #include <platform.h>
-#ifdef __STRICT_ANSI__
-#undef __STRICT_ANSI__
-#define __STRICT_ANSI_UNSET__ 1
-#endif
-#ifdef _NO_OLDNAMES
-#undef _NO_OLDNAMES
-#endif
-#ifdef _UWIN
-#undef _UWIN
-#endif
 #if PLATFORM(WINDOWS)
 #include <winsock2.h>
 #include <windows.h>
-#define __STDC_FORMAT_MACROS 1
 #endif
 
 #include <inttypes.h>
 #include <errno.h>
-#include <glib.h>
-#include <glib/gstdio.h>
-
 #include "qof.h"
 #include "qofquery-p.h"
 #include "qofquerycore-p.h"
@@ -72,6 +58,10 @@ extern "C"
 #endif
 
 }
+
+#include <glib.h>
+#include <glib/gstdio.h>
+
 #include <boost/regex.hpp>
 #include <string>
 #include <iomanip>
@@ -85,13 +75,6 @@ extern "C"
 #include "gnc-dbisqlresult.hpp"
 #include "gnc-dbisqlconnection.hpp"
 
-#if PLATFORM(WINDOWS)
-#ifdef __STRICT_ANSI_UNSET__
-#undef __STRICT_ANSI_UNSET__
-#define __STRICT_ANSI__ 1
-#endif
-#endif
-
 #if LIBDBI_VERSION >= 900
 #define HAVE_LIBDBI_R 1
 static dbi_inst dbi_instance = nullptr;
@@ -111,7 +94,8 @@ static QofLogModule log_module = G_LOG_DOMAIN;
 #define PGSQL_DEFAULT_PORT 5432
 
 static void adjust_sql_options (dbi_conn connection);
-static bool save_may_clobber_data (dbi_conn conn, const std::string& dbname);
+template<DbType Type> bool save_may_clobber_data (dbi_conn conn,
+                                                  const std::string& dbname);
 
 template <DbType Type>
 class QofDbiBackendProvider : public QofBackendProvider
@@ -152,19 +136,20 @@ struct UriStrings
 
 UriStrings::UriStrings(const std::string& uri)
 {
-    gchar *protocol, *host, *username, *password, *dbname;
+    gchar *scheme, *host, *username, *password, *dbname;
     int portnum;
-    gnc_uri_get_components(uri.c_str(), &protocol, &host, &portnum, &username,
+    gnc_uri_get_components(uri.c_str(), &scheme, &host, &portnum, &username,
                            &password, &dbname);
-    m_protocol = std::string{protocol};
+    m_protocol = std::string{scheme};
     m_host = std::string{host};
-    m_dbname = std::string{dbname};
+    if (dbname)
+	m_dbname = std::string{dbname};
     if (username)
         m_username = std::string{username};
     if (password)
         m_password = std::string{password};
     m_portnum = portnum;
-    g_free(protocol);
+    g_free(scheme);
     g_free(host);
     g_free(username);
     g_free(password);
@@ -205,7 +190,7 @@ set_options(dbi_conn conn, const PairVec& options)
         if (result < 0)
         {
             const char *msg = nullptr;
-            int err = dbi_conn_error(conn, &msg);
+            dbi_conn_error(conn, &msg);
             PERR("Error setting %s option to %s: %s", opt, val, msg);
             throw std::runtime_error(msg);
         }
@@ -374,25 +359,25 @@ error_handler<DbType::DBI_SQLITE> (dbi_conn conn, void* user_data)
 
 template <> void
 GncDbiBackend<DbType::DBI_SQLITE>::session_begin(QofSession* session,
-                                                 const char* book_id,
-                                                 bool ignore_lock,
-                                                 bool create, bool force)
+                                                 const char* new_uri,
+                                                 SessionOpenMode mode)
 {
     gboolean file_exists;
     PairVec options;
 
     g_return_if_fail (session != nullptr);
-    g_return_if_fail (book_id != nullptr);
+    g_return_if_fail (new_uri != nullptr);
 
     ENTER (" ");
 
     /* Remove uri type if present */
-    auto path = gnc_uri_get_path (book_id);
+    auto path = gnc_uri_get_path (new_uri);
     std::string filepath{path};
     g_free(path);
     GFileTest ftest = static_cast<decltype (ftest)> (
         G_FILE_TEST_IS_REGULAR | G_FILE_TEST_EXISTS) ;
     file_exists = g_file_test (filepath.c_str(), ftest);
+    bool create{mode == SESSION_NEW_STORE || mode == SESSION_NEW_OVERWRITE};
     if (!create && !file_exists)
     {
         set_error (ERR_FILEIO_FILE_NOT_FOUND);
@@ -405,12 +390,12 @@ GncDbiBackend<DbType::DBI_SQLITE>::session_begin(QofSession* session,
 
     if (create && file_exists)
     {
-        if (force)
+        if (mode == SESSION_NEW_OVERWRITE)
             g_unlink (filepath.c_str());
         else
         {
             set_error (ERR_BACKEND_STORE_EXISTS);
-            auto msg = "Might clobber, no force";
+            auto msg = "Might clobber, mode not SESSION_NEW_OVERWRITE";
             PWARN ("%s", msg);
             LEAVE("Error");
             return;
@@ -439,7 +424,7 @@ GncDbiBackend<DbType::DBI_SQLITE>::session_begin(QofSession* session,
     if (result < 0)
     {
         dbi_conn_close(conn);
-        PERR ("Unable to connect to %s: %d\n", book_id, result);
+        PERR ("Unable to connect to %s: %d\n", new_uri, result);
         set_error (ERR_BACKEND_BAD_URL);
         LEAVE("Error");
         return;
@@ -464,7 +449,7 @@ GncDbiBackend<DbType::DBI_SQLITE>::session_begin(QofSession* session,
     try
     {
         connect(new GncDbiSqlConnection(DbType::DBI_SQLITE,
-                                            this, conn, ignore_lock));
+                                            this, conn, mode));
     }
     catch (std::runtime_error& err)
     {
@@ -587,12 +572,21 @@ adjust_sql_options (dbi_conn connection)
         return;
     }
     PINFO("Initial sql_mode: %s", str.c_str());
-    if(str.find(SQL_OPTION_TO_REMOVE) == std::string::npos)
-        return;
+    if(str.find(SQL_OPTION_TO_REMOVE) != std::string::npos)
+        str = adjust_sql_options_string(str);
 
-    std::string adjusted_str{adjust_sql_options_string(str)};
-    PINFO("Setting sql_mode to %s", adjusted_str.c_str());
-    std::string set_str{"SET sql_mode='" + std::move(adjusted_str) + "'"};
+    //https://bugs.gnucash.org/show_bug.cgi?id=798112
+    const char* backslash_option{"NO_BACKSLASH_ESCAPES"};
+
+    if (str.find(backslash_option) == std::string::npos)
+    {
+        if (!str.empty())
+            str.append(",");
+        str.append(backslash_option);
+    }
+
+    PINFO("Setting sql_mode to %s", str.c_str());
+    std::string set_str{"SET sql_mode='" + std::move(str) + "'"};
     dbi_result set_result = dbi_conn_query(connection,
                                            set_str.c_str());
     if (set_result)
@@ -607,23 +601,59 @@ adjust_sql_options (dbi_conn connection)
     }
 }
 
+template <DbType Type> bool
+drop_database(dbi_conn conn, const UriStrings& uri)
+{
+    const char *root_db;
+    if (Type == DbType::DBI_PGSQL)
+    {
+        root_db = "template1";
+    }
+    else if (Type == DbType::DBI_MYSQL)
+    {
+        root_db = "mysql";
+    }
+    else
+    {
+        PERR ("Unknown database type, can't proceed.");
+        LEAVE("Error");
+        return false;
+    }
+    if (dbi_conn_select_db (conn, root_db) == -1)
+    {
+        PERR ("Failed to switch out of %s, drop will fail.",
+              uri.quote_dbname(Type).c_str());
+        LEAVE ("Error");
+        return false;
+    }
+    if (!dbi_conn_queryf (conn, "DROP DATABASE %s",
+                          uri.quote_dbname(Type).c_str()))
+    {
+        PERR ("Failed to drop database %s prior to recreating it."
+              "Proceeding would combine old and new data.",
+              uri.quote_dbname(Type).c_str());
+        LEAVE ("Error");
+        return false;
+    }
+    return true;
+}
 
 template <DbType Type> void
-GncDbiBackend<Type>::session_begin (QofSession* session, const char* book_id,
-                                    bool ignore_lock, bool create, bool force)
+GncDbiBackend<Type>::session_begin (QofSession* session, const char* new_uri,
+                                    SessionOpenMode mode)
 {
     GncDbiTestResult dbi_test_result = GNC_DBI_PASS;
     PairVec options;
 
     g_return_if_fail (session != nullptr);
-    g_return_if_fail (book_id != nullptr);
+    g_return_if_fail (new_uri != nullptr);
 
     ENTER (" ");
 
     /* Split the book-id
      * Format is protocol://username:password@hostname:port/dbname
      where username, password and port are optional) */
-    UriStrings uri(book_id);
+    UriStrings uri(new_uri);
 
     if (Type == DbType::DBI_PGSQL)
     {
@@ -631,7 +661,7 @@ GncDbiBackend<Type>::session_begin (QofSession* session, const char* book_id,
             uri.m_portnum = PGSQL_DEFAULT_PORT;
         /* Postgres's SQL interface coerces identifiers to lower case, but the
          * C interface is case-sensitive. This results in a mixed-case dbname
-         * being created (with a lower case name) but then dbi can't conect to
+         * being created (with a lower case name) but then dbi can't connect to
          * it. To work around this, coerce the name to lowercase first. */
         auto lcname = g_utf8_strdown (uri.dbname(), -1);
         uri.m_dbname = std::string{lcname};
@@ -639,6 +669,7 @@ GncDbiBackend<Type>::session_begin (QofSession* session, const char* book_id,
     }
     connect(nullptr);
 
+    bool create{mode == SESSION_NEW_STORE || mode == SESSION_NEW_OVERWRITE};
     auto conn = conn_setup(options, uri);
     if (conn == nullptr)
     {
@@ -658,31 +689,25 @@ GncDbiBackend<Type>::session_begin (QofSession* session, const char* book_id,
             LEAVE("Error");
             return;
         }
-        if (create && save_may_clobber_data (conn, uri.quote_dbname(Type)))
+        bool create = (mode == SESSION_NEW_STORE ||
+                       mode == SESSION_NEW_OVERWRITE);
+        if (create && save_may_clobber_data<Type>(conn, uri.quote_dbname(Type)))
         {
-            if (force)
+            if (mode == SESSION_NEW_OVERWRITE)
             {
-                // Drop DB
-                if (Type == DbType::DBI_PGSQL)
-                    dbi_conn_select_db (conn, "template1");
-                else if (Type == DbType::DBI_MYSQL)
-                    dbi_conn_select_db (conn, "mysql");
-                else
-                    PWARN ("Unknown database type, don't know how to connect to a system database. Dropping existing database may fail.");
-
-                if (!dbi_conn_queryf (conn, "DROP DATABASE %s",
-                                 uri.quote_dbname(Type).c_str()))
-                    PWARN ("Failed to drop database %s prior to recreating it. Creation will likely fail.",
-                           uri.quote_dbname(Type).c_str());
+                if (!drop_database<Type>(conn, uri))
+                    return;
             }
             else
             {
                 set_error (ERR_BACKEND_STORE_EXISTS);
-                PWARN ("Databse already exists, Might clobber it.");
+                PWARN ("Database already exists, Might clobber it.");
                 dbi_conn_close(conn);
                 LEAVE("Error");
                 return;
             }
+            /* Drop successful. */
+            m_exists = false;
         }
 
     }
@@ -739,7 +764,7 @@ GncDbiBackend<Type>::session_begin (QofSession* session, const char* book_id,
     connect(nullptr);
     try
     {
-        connect(new GncDbiSqlConnection(Type, this, conn, ignore_lock));
+        connect(new GncDbiSqlConnection(Type, this, conn, mode));
     }
     catch (std::runtime_error& err)
     {
@@ -882,7 +907,7 @@ GncDbiBackend<Type>::load (QofBook* book, QofBackendLoadType loadType)
 
 /* ================================================================= */
 /* This is used too early to call GncDbiProvider::get_table_list(). */
-static bool
+template <DbType T> bool
 save_may_clobber_data (dbi_conn conn, const std::string& dbname)
 {
 
@@ -897,6 +922,23 @@ save_may_clobber_data (dbi_conn conn, const std::string& dbname)
     return retval;
 }
 
+template <> bool
+save_may_clobber_data <DbType::DBI_PGSQL>(dbi_conn conn,
+                                          const std::string& dbname)
+{
+
+    /* Data may be clobbered iff the number of tables != 0 */
+    const char* query = "SELECT relname FROM pg_class WHERE relname !~ '^(pg|sql)_' AND relkind = 'r' ORDER BY relname";
+    auto result = dbi_conn_query (conn, query);
+    bool retval = false;
+    if (result)
+    {
+        retval =  dbi_result_get_numrows (result) > 0;
+        dbi_result_free (result);
+    }
+    return retval;
+}
+
 
 /**
  * Safely resave a database by renaming all of its tables, recreating
