@@ -24,8 +24,6 @@
 extern "C"
 {
 #include <config.h>
-
-#include <glib.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -35,6 +33,8 @@ extern "C"
 #include "gncTaxTableP.h"
 }
 
+#include <glib.h>
+
 #include "gnc-xml-helper.h"
 #include "sixtp.h"
 #include "sixtp-utils.h"
@@ -244,7 +244,7 @@ set_time64 (xmlNodePtr node, GncEntry* entry,
               void (*func) (GncEntry* entry, time64 ts))
 {
     time64 time = dom_tree_to_time64 (node);
-    if (!dom_tree_valid_time64 (time, node->name)) return FALSE;
+    if (!dom_tree_valid_time64 (time, node->name)) time = 0;
     func (entry, time);
     return TRUE;
 }
@@ -283,7 +283,7 @@ set_account (xmlNodePtr node, struct entry_pdata* pdata,
     guid = dom_tree_to_guid (node);
     g_return_val_if_fail (guid, FALSE);
     acc = xaccAccountLookup (guid, pdata->book);
-    g_free (guid);
+    guid_free (guid);
     g_return_val_if_fail (acc, FALSE);
 
     if (func)
@@ -314,7 +314,7 @@ set_taxtable (xmlNodePtr node, struct entry_pdata* pdata,
         gncTaxTableDecRef (taxtable);
 
     func (pdata->entry, taxtable);
-    g_free (guid);
+    guid_free (guid);
     return TRUE;
 }
 
@@ -339,7 +339,7 @@ entry_guid_handler (xmlNodePtr node, gpointer entry_pdata)
         gncEntrySetGUID (pdata->entry, guid);
     }
 
-    g_free (guid);
+    guid_free (guid);
 
     return TRUE;
 }
@@ -579,7 +579,7 @@ entry_order_handler (xmlNodePtr node, gpointer entry_pdata)
     gncOrderAddEntry (order, pdata->entry);
     gncOrderCommitEdit (order);
 
-    g_free (guid);
+    guid_free (guid);
     return TRUE;
 }
 
@@ -604,7 +604,7 @@ entry_invoice_handler (xmlNodePtr node, gpointer entry_pdata)
     gncInvoiceAddEntry (invoice, pdata->entry);
     gncInvoiceCommitEdit (invoice);
 
-    g_free (guid);
+    guid_free (guid);
     return TRUE;
 }
 
@@ -629,7 +629,7 @@ entry_bill_handler (xmlNodePtr node, gpointer entry_pdata)
     gncBillAddEntry (invoice, pdata->entry);
     gncInvoiceCommitEdit (invoice);
 
-    g_free (guid);
+    guid_free (guid);
     return TRUE;
 }
 
