@@ -24,8 +24,6 @@
 extern "C"
 {
 #include <config.h>
-
-#include <glib.h>
 #include <string.h>
 #include "AccountP.h"
 #include "Transaction.h"
@@ -33,6 +31,7 @@ extern "C"
 #include "gnc-lot.h"
 #include "gnc-lot-p.h"
 }
+#include <glib.h>
 #include "gnc-xml-helper.h"
 
 #include "sixtp.h"
@@ -63,15 +62,6 @@ add_time64 (xmlNodePtr node, const gchar * tag, time64 time, gboolean always)
         xmlAddChild (node, time64_to_dom_tree (tag, time));
 }
 
-static void
-add_timespec (xmlNodePtr node, const gchar* tag, Timespec tms, gboolean always)
-{
-    if (always || tms.tv_sec)
-    {
-        xmlAddChild (node, time64_to_dom_tree (tag, tms.tv_sec));
-    }
-}
-
 static xmlNodePtr
 split_to_dom_tree (const gchar* tag, Split* spl)
 {
@@ -113,8 +103,8 @@ split_to_dom_tree (const gchar* tag, Split* spl)
                          BAD_CAST tmp);
     }
 
-    add_timespec (ret, "split:reconcile-date",
-                  xaccSplitRetDateReconciledTS (spl), FALSE);
+    add_time64 (ret, "split:reconcile-date",
+                xaccSplitGetDateReconciled (spl), FALSE);
 
     add_gnc_num (ret, "split:value", xaccSplitGetValue (spl));
 
@@ -246,7 +236,7 @@ spl_id_handler (xmlNodePtr node, gpointer data)
 
     xaccSplitSetGUID (pdata->split, tmp);
 
-    g_free (tmp);
+    guid_free (tmp);
     return TRUE;
 }
 
@@ -283,7 +273,7 @@ spl_reconcile_date_handler (xmlNodePtr node, gpointer data)
 {
     struct split_pdata* pdata = static_cast<decltype (pdata)> (data);
     time64 time  = dom_tree_to_time64 (node);
-    if (!dom_tree_valid_time64 (time, node->name)) return FALSE;
+    if (!dom_tree_valid_time64 (time, node->name)) time = 0;
     xaccSplitSetDateReconciledSecs (pdata->split, time);
     return TRUE;
 }
@@ -325,7 +315,7 @@ spl_account_handler (xmlNodePtr node, gpointer data)
 
     xaccAccountInsertSplit (account, pdata->split);
 
-    g_free (id);
+    guid_free (id);
 
     return TRUE;
 }
@@ -349,7 +339,7 @@ spl_lot_handler (xmlNodePtr node, gpointer data)
 
     gnc_lot_add_split (lot, pdata->split);
 
-    g_free (id);
+    guid_free (id);
 
     return TRUE;
 }
@@ -438,19 +428,18 @@ set_tran_time64 (xmlNodePtr node, Transaction * trn,
         void (*func) (Transaction *, time64))
 {
     time64 time = dom_tree_to_time64 (node);
-    if (!dom_tree_valid_time64 (time, node->name)) return FALSE;
+    if (!dom_tree_valid_time64 (time, node->name)) time = 0;
     func (trn, time);
     return TRUE;
 }
 
 static inline gboolean
 set_tran_date (xmlNodePtr node, Transaction* trn,
-               void (*func) (Transaction* trn, const Timespec* tm))
+               void (*func) (Transaction* trn, const time64 tm))
 {
     time64 time = dom_tree_to_time64 (node);
-    if (!dom_tree_valid_time64 (time, node->name)) return FALSE;
-    Timespec ts {time, 0};
-    func (trn, &ts);
+    if (!dom_tree_valid_time64 (time, node->name)) time = 0;
+    func (trn, time);
     return TRUE;
 }
 
@@ -465,7 +454,7 @@ trn_id_handler (xmlNodePtr node, gpointer trans_pdata)
 
     xaccTransSetGUID ((Transaction*)trn, tmp);
 
-    g_free (tmp);
+    guid_free (tmp);
 
     return TRUE;
 }
