@@ -27,8 +27,6 @@ extern "C"
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/stat.h>
-#include <glib.h>
-#include <glib/gstdio.h>
 #include <regex.h>
 
 #include <gnc-engine.h> //for GNC_MOD_BACKEND
@@ -38,6 +36,8 @@ extern "C"
 
 }
 
+#include <glib.h>
+#include <glib/gstdio.h>
 #include <sstream>
 
 #include "gnc-xml-backend.hpp"
@@ -49,6 +49,11 @@ extern "C"
 #define FILE_URI_PREFIX "file://"
 static QofLogModule log_module = GNC_MOD_BACKEND;
 
+GncXmlBackend::~GncXmlBackend()
+{
+    session_end();
+};
+
 bool
 GncXmlBackend::check_path (const char* fullpath, bool create)
 {
@@ -314,6 +319,13 @@ GncXmlBackend::sync(QofBook* book)
     remove_old_files();
 }
 
+void
+GncXmlBackend::commit(QofInstance* instance)
+{
+    if (qof_instance_is_dirty(instance))
+        qof_instance_mark_clean(instance);
+}
+
 bool
 GncXmlBackend::save_may_clobber_data()
 {
