@@ -36,8 +36,6 @@ extern "C"
 #endif
 #include <windows.h>
 #endif
-#include <glib.h>
-#include <glib/gstdio.h>
 #include <fcntl.h>
 #include <string.h>
 #ifdef HAVE_UNISTD_H
@@ -66,6 +64,9 @@ extern "C"
 #endif
 }
 
+#include <glib.h>
+#include <glib/gstdio.h>
+
 #include "gnc-xml-backend.hpp"
 #include "sixtp-parsers.h"
 #include "sixtp-utils.h"
@@ -77,7 +78,7 @@ extern "C"
 
 /* Do not treat -Wstrict-aliasing warnings as errors because of problems of the
  * G_LOCK* macros as declared by glib.  See
- * http://bugzilla.gnome.org/show_bug.cgi?id=316221 for additional information.
+ * https://bugs.gnucash.org/show_bug.cgi?id=316221 for additional information.
  */
 #if (__GNUC__ >= 4 && __GNUC_MINOR__ >= 2)
 #    pragma GCC diagnostic warning "-Wstrict-aliasing"
@@ -791,7 +792,7 @@ qof_session_load_from_xml_file_v2_full (
         /* Even though libxml2 knows how to decompress zipped files, we
          * do it ourself since as of version 2.9.1 it has a bug that
          * causes it to fail to decompress certain files. See
-         * https://bugzilla.gnome.org/show_bug.cgi?id=712528 for more
+         * https://bugs.gnucash.org/show_bug.cgi?id=712528 for more
          * info.
          */
          const char* filename = xml_be->get_filename();
@@ -853,6 +854,9 @@ qof_session_load_from_xml_file_v2_full (
     gnc_account_foreach_descendant (root,
                                     (AccountCb) xaccAccountCommitEdit,
                                     NULL);
+    gnc_account_foreach_descendant (gnc_book_get_template_root (book),
+                                    (AccountCb) xaccAccountCommitEdit,
+                                    NULL);
 
     /* start logging again */
     xaccLogEnable ();
@@ -981,31 +985,6 @@ write_book (FILE* out, QofBook* book, sixtp_gdv2* gd)
 {
     struct file_backend be_data;
 
-#ifdef IMPLEMENT_BOOK_DOM_TREES_LATER
-    /* We can't just blast out the dom tree, because the dom tree
-     * doesn't have the books, transactions, etc underneath it.
-     * But that is just as well, since I think the performance
-     * will be much better if we write out as we go along
-     */
-    xmlNodePtr node;
-
-    node = gnc_book_dom_tree_create (book);
-
-    if (!node)
-    {
-        return FALSE;
-    }
-
-    xmlElemDump (out, NULL, node);
-    xmlFreeNode (node);
-
-    if (ferror (out) || fprintf (out, "\n") < 0)
-    {
-        return FALSE;
-    }
-
-#endif
-
     be_data.out = out;
     be_data.book = book;
     be_data.gd = gd;
@@ -1539,7 +1518,6 @@ try_gz_open (const char* filename, const char* perms, gboolean use_gzip,
     {
         int filedes[2];
         GThread* thread;
-        GError* error = NULL;
         gz_thread_params_t* params;
         FILE* file;
 
@@ -1564,9 +1542,7 @@ try_gz_open (const char* filename, const char* perms, gboolean use_gzip,
                                params);
         if (!thread)
         {
-            g_warning ("Could not create thread for (de)compression: %s",
-                       error->message);
-            g_error_free (error);
+            g_warning ("Could not create thread for (de)compression.");
             g_free (params->filename);
             g_free (params->perms);
             g_free (params);
@@ -1626,8 +1602,7 @@ gnc_book_write_to_xml_file_v2 (
 
     /* Try to write as much as possible */
     if (!out
-        || !gnc_book_write_to_xml_filehandle_v2 (book, out)
-        || !write_emacs_trailer (out))
+        || !gnc_book_write_to_xml_filehandle_v2 (book, out))
         success = FALSE;
 
     /* Close the output stream */
@@ -1645,7 +1620,7 @@ gnc_book_write_to_xml_file_v2 (
 /*
  * Have to pass in the backend as this routine needs the temporary
  * backend for file export, not the real backend which could be
- * postgress or anything else.
+ * postgresql or anything else.
  */
 gboolean
 gnc_book_write_accounts_to_xml_file_v2 (QofBackend* qof_be, QofBook* book,
@@ -1658,8 +1633,7 @@ gnc_book_write_accounts_to_xml_file_v2 (QofBackend* qof_be, QofBook* book,
 
     /* Try to write as much as possible */
     if (!out
-        || !gnc_book_write_accounts_to_xml_filehandle_v2 (qof_be, book, out)
-        || !write_emacs_trailer (out))
+        || !gnc_book_write_accounts_to_xml_filehandle_v2 (qof_be, book, out))
         success = FALSE;
 
     /* Close the output stream */
@@ -1868,6 +1842,7 @@ gnc_xml2_find_ambiguous (const gchar* filename, GList* encodings,
         if (iconv_item->iconv == (GIConv) - 1)
         {
             PWARN ("Unable to open IConv conversion descriptor for '%s'", enc);
+            g_free (iconv_item);
             goto cleanup_find_ambs;
         }
         else
@@ -2176,6 +2151,7 @@ gnc_xml2_parse_with_subst (GncXmlBackend* xml_be, QofBook* book, GHashTable* sub
     success = qof_session_load_from_xml_file_v2_full (
                   xml_be, book, (sixtp_push_handler) parse_with_subst_push_handler,
                   push_data, GNC_BOOK_XML2_FILE);
+    g_free (push_data);
 
     if (success)
         qof_instance_set_dirty (QOF_INSTANCE (book));
