@@ -256,6 +256,12 @@ void gnc_book_set_root_account(QofBook *book, Account *root);
 
 /** @} */
 
+/*  Tests account and descendants -- if all have no splits then return TRUE.
+ *  Otherwise if any account or its descendants have split return FALSE.
+ */
+
+gboolean gnc_account_and_descendants_empty (Account *acc);
+
 /** Composes a translatable error message showing which account
  *  names clash with the current account separator. Can be called
  *  after gnc_account_list_name_violations to have a consistent
@@ -770,7 +776,7 @@ GList * gnc_account_get_descendants (const Account *account);
  *
  *  Note: Use this function where the results are intended for display
  *  to the user.  If the results are internal to GnuCash or will be
- *  resorted at som later point in time you should use the
+ *  resorted at some later point in time you should use the
  *  gnc_account_get_descendants() function.
  *
  *  @param account The account whose descendants should be returned.
@@ -924,6 +930,32 @@ Account *gnc_account_lookup_by_full_name (const Account *any_account,
 Account *gnc_account_lookup_by_code (const Account *parent,
                                      const char *code);
 
+/** Find the opening balance account for the currency.
+ *
+ *  @param account The account of which the sought-for account is a descendant.
+ *  @param commodity The commodity in which the account should be denominated
+ *  @return The descendant account of EQUITY_TYPE_OPENING_BALANCE or NULL if one doesn't exist.
+ */
+Account *gnc_account_lookup_by_opening_balance (Account *account, gnc_commodity *commodity);
+
+/** Find a direct child account matching name, GNCAccountType, and commodity.
+ *
+ * Note that commodity matching is by equivalence: If the
+ * mnemonic/symbol and namespace are the same, it matches.
+ *
+ *  @param root The account among whose children one expects to find
+ *  the account.
+ *  @param name The name of the account to look for. If nullptr the
+ *  returned account will match only on acctype and commodity.
+ *  @param acctype The GNCAccountType to match.
+ *  @param commodity The commodity in which the account should be denominated.
+ *  @return The book's trading account for the given commodity if
+ *  trading accounts are enabled and one exists; NULL otherwise.
+ */
+Account *gnc_account_lookup_by_type_and_commodity (Account* root,
+                                                   const char* name,
+                                                   GNCAccountType acctype,
+                                                   gnc_commodity* commodity);
 /** @} */
 
 /* ------------------ */
@@ -1020,7 +1052,9 @@ SplitList* xaccAccountGetSplitList (const Account *account);
 
 
 /** The xaccAccountCountSplits() routine returns the number of all
- *    the splits in the account.
+ *    the splits in the account. xaccAccountCountSplits is O(N). if
+ *    testing for emptiness, use xaccAccountGetSplitList != NULL.
+
  * @param acc the account for which to count the splits
  *
  * @param include_children also count splits in descendants (TRUE) or
@@ -1183,6 +1217,22 @@ gboolean xaccAccountGetPlaceholder (const Account *account);
  *  @param val The new state for the account's "placeholder" flag. */
 void xaccAccountSetPlaceholder (Account *account, gboolean val);
 
+/** Get the "opening-balance" flag for an account.  If this flag is set
+ *  then the account is used for opening balance transactions.
+ *
+ *  @param account The account whose flag should be retrieved.
+ *
+ *  @return The current state of the account's "opening-balance" flag. */
+gboolean xaccAccountGetIsOpeningBalance (const Account *account);
+
+/** Set the "opening-balance" flag for an account. If this flag is set
+ *  then the account is used for opening balance transactions.
+ *
+ *  @param account The account whose flag should be set.
+ *
+ *  @param val The new state for the account's "opening-balance" flag. */
+void xaccAccountSetIsOpeningBalance (Account *account, gboolean val);
+
 /** Returns PLACEHOLDER_NONE if account is NULL or neither account nor
  *  any descendant of account is a placeholder.  If account is a
  *  placeholder, returns PLACEHOLDER_THIS.  Otherwise, if any
@@ -1444,7 +1494,7 @@ int xaccAccountTreeForEachTransaction(Account *acc,
  */
 GncImportMatchMap *gnc_account_imap_create_imap (Account *acc);
 
-/* Look up an Account in the map non Baysian
+/* Look up an Account in the map non-Baysian
  */
 Account* gnc_account_imap_find_account (GncImportMatchMap *imap, const char* category,
                                         const char *key);
@@ -1560,6 +1610,7 @@ const char * dxaccAccountGetQuoteTZ (const Account *account);
 #define ACCOUNT_NOTES_		"notes"
 #define ACCOUNT_BALANCE_	"balance"
 #define ACCOUNT_NOCLOSING_	"noclosing"
+#define ACCOUNT_OPENING_BALANCE_ "opening-balance"
 #define ACCOUNT_CLEARED_	"cleared"
 #define ACCOUNT_RECONCILED_	"reconciled"
 #define ACCOUNT_PRESENT_	"present"
