@@ -47,7 +47,6 @@
 #include "Account.h"
 #include "AccountP.h"
 #include "Scrub.h"
-#include "ScrubP.h"
 #include "Transaction.h"
 #include "TransactionP.h"
 #include "gnc-commodity.h"
@@ -60,12 +59,26 @@ static QofLogModule log_module = G_LOG_DOMAIN;
 static gboolean abort_now = FALSE;
 static gint scrub_depth = 0;
 
+
+static Account* xaccScrubUtilityGetOrMakeAccount (Account *root,
+                                                  gnc_commodity* currency,
+                                                  const char* accname,
+                                                  GNCAccountType acctype,
+                                                  gboolean placeholder,
+                                                  gboolean checkname);
+
 void
 gnc_set_abort_scrub (gboolean abort)
 {
     abort_now = abort;
 }
 
+gboolean
+gnc_get_abort_scrub (void)
+{
+    return abort_now;
+}
+
 gboolean
 gnc_get_ongoing_scrub (void)
 {
@@ -78,6 +91,10 @@ void
 xaccAccountTreeScrubOrphans (Account *acc, QofPercentageFunc percentagefunc)
 {
     if (!acc) return;
+
+    if (abort_now)
+        (percentagefunc)(NULL, -1.0);
+
     scrub_depth ++;
     xaccAccountScrubOrphans (acc, percentagefunc);
     gnc_account_foreach_descendant(acc,
@@ -102,13 +119,14 @@ TransScrubOrphansFast (Transaction *trans, Account *root)
 
         if (split->acc) continue;
 
-        DEBUG ("Found an orphan \n");
+        DEBUG ("Found an orphan\n");
 
         accname = g_strconcat (_("Orphan"), "-",
                                gnc_commodity_get_mnemonic (trans->common_currency),
                                NULL);
         orph = xaccScrubUtilityGetOrMakeAccount (root, trans->common_currency,
-                                                 accname, ACCT_TYPE_BANK, FALSE);
+                                                 accname, ACCT_TYPE_BANK,
+                                                 FALSE, TRUE);
         g_free (accname);
         if (!orph) continue;
 
@@ -130,7 +148,7 @@ xaccAccountScrubOrphans (Account *acc, QofPercentageFunc percentagefunc)
 
     str = xaccAccountGetName (acc);
     str = str ? str : "(null)";
-    PINFO ("Looking for orphans in account %s \n", str);
+    PINFO ("Looking for orphans in account %s\n", str);
     splits = xaccAccountGetSplitList(acc);
     total_splits = g_list_length (splits);
 
@@ -314,6 +332,11 @@ xaccSplitScrub (Split *split)
 void
 xaccAccountTreeScrubImbalance (Account *acc, QofPercentageFunc percentagefunc)
 {
+    if (!acc) return;
+
+    if (abort_now)
+        (percentagefunc)(NULL, -1.0);
+
     scrub_depth++;
     xaccAccountScrubImbalance (acc, percentagefunc);
     gnc_account_foreach_descendant(acc,
@@ -334,7 +357,7 @@ xaccAccountScrubImbalance (Account *acc, QofPercentageFunc percentagefunc)
 
     str = xaccAccountGetName(acc);
     str = str ? str : "(null)";
-    PINFO ("Looking for imbalances in account %s \n", str);
+    PINFO ("Looking for imbalances in account %s\n", str);
 
     splits = xaccAccountGetSplitList(acc);
     split_count = g_list_length (splits);
@@ -392,7 +415,8 @@ get_balance_split (Transaction *trans, Account *root, Account *account,
         accname = g_strconcat (_("Imbalance"), "-",
                                gnc_commodity_get_mnemonic (commodity), NULL);
         account = xaccScrubUtilityGetOrMakeAccount (root, commodity,
-                                                    accname, ACCT_TYPE_BANK, FALSE);
+                                                    accname, ACCT_TYPE_BANK,
+                                                    FALSE, TRUE);
         g_free (accname);
         if (!account)
         {
@@ -455,7 +479,8 @@ get_trading_split (Transaction *trans, Account *root,
     trading_account = xaccScrubUtilityGetOrMakeAccount (root,
                                                         default_currency,
                                                         _("Trading"),
-                                                        ACCT_TYPE_TRADING, TRUE);
+                                                        ACCT_TYPE_TRADING,
+                                                        TRUE, FALSE);
     if (!trading_account)
     {
         PERR ("Can't get trading account");
@@ -465,7 +490,8 @@ get_trading_split (Transaction *trans, Account *root,
     ns_account = xaccScrubUtilityGetOrMakeAccount (trading_account,
                                                    default_currency,
                                                    gnc_commodity_get_namespace(commodity),
-                                                   ACCT_TYPE_TRADING, TRUE);
+                                                   ACCT_TYPE_TRADING,
+                                                   TRUE, TRUE);
     if (!ns_account)
     {
         PERR ("Can't get namespace account");
@@ -474,7 +500,8 @@ get_trading_split (Transaction *trans, Account *root,
 
     account = xaccScrubUtilityGetOrMakeAccount (ns_account, commodity,
                                                 gnc_commodity_get_mnemonic(commodity),
-                                                ACCT_TYPE_TRADING, FALSE);
+                                                ACCT_TYPE_TRADING,
+                                                FALSE, FALSE);
     if (!account)
     {
         PERR ("Can't get commodity account");
@@ -1426,7 +1453,7 @@ xaccAccountScrubColorNotSet (QofBook *book)
 Account *
 xaccScrubUtilityGetOrMakeAccount (Account *root, gnc_commodity * currency,
                                   const char *accname, GNCAccountType acctype,
-                                  gboolean placeholder)
+                                  gboolean placeholder, gboolean checkname)
 {
     Account * acc;
 
@@ -1440,7 +1467,9 @@ xaccScrubUtilityGetOrMakeAccount (Account *root, gnc_commodity * currency,
     }
 
     /* See if we've got one of these going already ... */
-    acc = gnc_account_lookup_by_name(root, accname);
+    acc = gnc_account_lookup_by_type_and_commodity (root,
+                                                    checkname ? accname : NULL,
+                                                    acctype, currency);
 
     if (acc == NULL)
     {
