@@ -115,12 +115,12 @@ gnc_split_init(Split* split)
     split->amount      = gnc_numeric_zero();
     split->value       = gnc_numeric_zero();
 
-    split->date_reconciled.tv_sec  = 0;
-    split->date_reconciled.tv_nsec = 0;
+    split->date_reconciled  = 0;
 
     split->balance             = gnc_numeric_zero();
     split->cleared_balance     = gnc_numeric_zero();
     split->reconciled_balance  = gnc_numeric_zero();
+    split->noclosing_balance   = gnc_numeric_zero();
 
     split->gains = GAINS_STATUS_UNKNOWN;
     split->gains_split = NULL;
@@ -151,6 +151,7 @@ gnc_split_get_property(GObject         *object,
 {
     Split *split;
     gchar *key;
+    Time64 t;
 
     g_return_if_fail(GNC_IS_SPLIT(object));
 
@@ -170,7 +171,8 @@ gnc_split_get_property(GObject         *object,
             g_value_set_boxed(value, &split->amount);
             break;
         case PROP_RECONCILE_DATE:
-            g_value_set_boxed(value, &split->date_reconciled);
+            t.t = split->date_reconciled;
+            g_value_set_boxed(value, &t);
             break;
         case PROP_TX:
             g_value_take_object(value, split->parent);
@@ -223,7 +225,7 @@ gnc_split_set_property(GObject         *object,
     Split *split;
     gnc_numeric* number;
     gchar *key;
-
+    Time64 *t;
     g_return_if_fail(GNC_IS_SPLIT(object));
 
     split = GNC_SPLIT(object);
@@ -247,7 +249,8 @@ gnc_split_set_property(GObject         *object,
             xaccSplitSetAmount(split, *number);
             break;
         case PROP_RECONCILE_DATE:
-            xaccSplitSetDateReconciledTS(split, g_value_get_boxed(value));
+            t = g_value_get_boxed(value);
+            xaccSplitSetDateReconciledSecs(split, t->t);
             break;
         case PROP_TX:
             xaccSplitSetParent(split, g_value_get_object(value));
@@ -353,7 +356,7 @@ gnc_split_class_init(SplitClass* klass)
          g_param_spec_boxed("reconcile-date",
                             "Reconcile Date",
                             "The date this split was reconciled.",
-                            GNC_TYPE_TIMESPEC,
+                            GNC_TYPE_TIME64,
                             G_PARAM_READWRITE));
 
     g_object_class_install_property
@@ -506,12 +509,12 @@ xaccSplitReinit(Split * split)
     split->amount      = gnc_numeric_zero();
     split->value       = gnc_numeric_zero();
 
-    split->date_reconciled.tv_sec  = 0;
-    split->date_reconciled.tv_nsec = 0;
+    split->date_reconciled  = 0;
 
     split->balance             = gnc_numeric_zero();
     split->cleared_balance     = gnc_numeric_zero();
     split->reconciled_balance  = gnc_numeric_zero();
+    split->noclosing_balance   = gnc_numeric_zero();
 
     qof_instance_set_idata(split, 0);
 
@@ -596,6 +599,7 @@ xaccSplitCloneNoKvp (const Split *s)
     split->balance             = s->balance;
     split->cleared_balance     = s->cleared_balance;
     split->reconciled_balance  = s->reconciled_balance;
+    split->noclosing_balance   = s->noclosing_balance;
 
     split->gains = GAINS_STATUS_UNKNOWN;
     split->gains_split = NULL;
@@ -653,6 +657,9 @@ xaccSplitCopyOnto(const Split *from_split, Split *to_split)
 void
 xaccSplitDump (const Split *split, const char *tag)
 {
+    char datebuff[MAX_DATE_LENGTH + 1];
+    memset (datebuff, 0, sizeof(datebuff));
+    qof_print_date_buff (datebuff, MAX_DATE_LENGTH, split->date_reconciled);
     printf("  %s Split %p", tag, split);
     printf("    Book:     %p\n", qof_instance_get_book(split));
     printf("    Account:  %p (%s)\n", split->acc,
@@ -667,14 +674,15 @@ xaccSplitDump (const Split *split, const char *tag)
     printf("    Memo:     %s\n", split->memo ? split->memo : "(null)");
     printf("    Action:   %s\n", split->action ? split->action : "(null)");
     printf("    KVP Data: %s\n", qof_instance_kvp_as_string (QOF_INSTANCE (split)));
-    printf("    Recncld:  %c (date %s)\n", split->reconciled,
-           gnc_print_date(split->date_reconciled));
+    printf("    Recncld:  %c (date %s)\n", split->reconciled, datebuff);
+
     printf("    Value:    %s\n", gnc_numeric_to_string(split->value));
     printf("    Amount:   %s\n", gnc_numeric_to_string(split->amount));
     printf("    Balance:  %s\n", gnc_numeric_to_string(split->balance));
     printf("    CBalance: %s\n", gnc_numeric_to_string(split->cleared_balance));
     printf("    RBalance: %s\n",
            gnc_numeric_to_string(split->reconciled_balance));
+    printf("    NoClose:  %s\n", gnc_numeric_to_string(split->noclosing_balance));
     printf("    idata:    %x\n", qof_instance_get_idata(split));
 }
 #endif
@@ -707,8 +715,7 @@ xaccFreeSplit (Split *split)
     split->acc         = NULL;
     split->orig_acc    = NULL;
 
-    split->date_reconciled.tv_sec = 0;
-    split->date_reconciled.tv_nsec = 0;
+    split->date_reconciled = 0;
     G_OBJECT_CLASS (QOF_INSTANCE_GET_CLASS (&split->inst))->dispose(G_OBJECT (split));
     // Is this right?
     if (split->gains_split) split->gains_split->gains_split = NULL;
@@ -817,7 +824,7 @@ xaccSplitEqual(const Split *sa, const Split *sb,
         return FALSE;
     }
 
-    if (timespec_cmp(&(sa->date_reconciled), &(sb->date_reconciled)))
+    if (sa->date_reconciled != sb->date_reconciled)
     {
         PINFO ("reconciled date differs");
         return FALSE;
@@ -865,6 +872,9 @@ xaccSplitEqual(const Split *sa, const Split *sb,
         if (!xaccSplitEqualCheckBal ("reconciled ", sa->reconciled_balance,
                                      sb->reconciled_balance))
             return FALSE;
+        if (!xaccSplitEqualCheckBal ("noclosing ", sa->noclosing_balance,
+                                     sb->noclosing_balance))
+            return FALSE;
     }
 
     if (!xaccTransEqual(sa->parent, sb->parent, check_guids, check_txn_splits,
@@ -883,21 +893,32 @@ xaccSplitEqual(const Split *sa, const Split *sb,
  * xaccSplitListGetUniqueTransactions
  ********************************************************************/
 GList *
-xaccSplitListGetUniqueTransactions(const GList *splits)
+xaccSplitListGetUniqueTransactionsReversed (const GList *splits)
 {
-    const GList *snode;
+    GHashTable *txn_hash = g_hash_table_new (NULL, NULL);
     GList *transList = NULL;
+    const GList *snode;
 
-    for(snode = splits; snode; snode = snode->next)
+    for (snode = splits; snode; snode = snode->next)
     {
         Transaction *trans = xaccSplitGetParent((Split *)(snode->data));
 
-        GList *item = g_list_find (transList, trans);
-        if (item == NULL)
-            transList = g_list_append (transList, trans);
+        if (g_hash_table_contains (txn_hash, trans))
+            continue;
+
+        g_hash_table_insert (txn_hash, trans, NULL);
+        transList = g_list_prepend (transList, trans);
     }
+    g_hash_table_destroy (txn_hash);
     return transList;
 }
+
+GList *
+xaccSplitListGetUniqueTransactions(const GList *splits)
+{
+    return g_list_reverse (xaccSplitListGetUniqueTransactionsReversed (splits));
+}
+
 /*################## Added for Reg2 #################*/
 
 
@@ -1108,7 +1129,7 @@ get_currency_denom(const Split * s)
     }
     else if (!s->parent || !s->parent->common_currency)
     {
-        return 1000000; /* Max supported denom to avoid premature rounding. */
+        return GNC_COMMODITY_MAX_FRACTION;
     }
     else
     {
@@ -1125,7 +1146,7 @@ get_commodity_denom(const Split * s)
     }
     else if (!s->acc)
     {
-        return 1000000; /* Max supported denom to avoid premature rounding. */
+        return GNC_COMMODITY_MAX_FRACTION;
     }
     else
     {
@@ -1269,6 +1290,12 @@ xaccSplitGetBalance (const Split *s)
     return s ? s->balance : gnc_numeric_zero();
 }
 
+gnc_numeric
+xaccSplitGetNoclosingBalance (const Split *s)
+{
+    return s ? s->noclosing_balance : gnc_numeric_zero();
+}
+
 gnc_numeric
 xaccSplitGetClearedBalance (const Split *s)
 {
@@ -1444,6 +1471,7 @@ xaccSplitDestroy (Split *split)
     acc = split->acc;
     trans = split->parent;
     if (acc && !qof_instance_get_destroying(acc)
+        && !qof_instance_get_destroying(trans)
         && xaccTransGetReadOnly(trans))
         return FALSE;
 
@@ -1513,7 +1541,10 @@ xaccSplitOrder (const Split *sa, const Split *sb)
     if (comp > 0) return +1;
 
     /* if dates differ, return */
-    DATE_CMP(sa, sb, date_reconciled);
+    if (sa->date_reconciled < sb->date_reconciled)
+        return -1;
+    else if (sa->date_reconciled > sb->date_reconciled)
+        return 1;
 
     /* else, sort on guid - keeps sort stable. */
     retval = qof_instance_guid_compare(sa, sb);
@@ -1602,8 +1633,7 @@ xaccSplitGetCorrAccountCode(const Split *sa)
     if (!get_corr_account_split(sa, &other_split))
     {
         if (!split_const)
-            /* Translators: This string has a disambiguation prefix */
-            split_const = Q_("Displayed account code of the other account in a multi-split transaction|Split");
+            split_const = C_("Displayed account code of the other account in a multi-split transaction", "Split");
 
         return split_const;
     }
@@ -1771,44 +1801,18 @@ xaccSplitSetDateReconciledSecs (Split *split, time64 secs)
     if (!split) return;
     xaccTransBeginEdit (split->parent);
 
-    split->date_reconciled.tv_sec = secs;
-    split->date_reconciled.tv_nsec = 0;
+    split->date_reconciled = secs;
     qof_instance_set_dirty(QOF_INSTANCE(split));
     xaccTransCommitEdit(split->parent);
 
 }
 
-void
-xaccSplitSetDateReconciledTS (Split *split, Timespec *ts)
-{
-    if (!split || !ts) return;
-    xaccTransBeginEdit (split->parent);
-
-    split->date_reconciled = *ts;
-    qof_instance_set_dirty(QOF_INSTANCE(split));
-    xaccTransCommitEdit(split->parent);
-
-}
-
-void
-xaccSplitGetDateReconciledTS (const Split * split, Timespec *ts)
-{
-    if (!split || !ts) return;
-    *ts = (split->date_reconciled);
-}
-
-Timespec
-xaccSplitRetDateReconciledTS (const Split * split)
-{
-    Timespec ts = {0, 0};
-    return split ? split->date_reconciled : ts;
-}
 
 /*################## Added for Reg2 #################*/
 time64
 xaccSplitGetDateReconciled (const Split * split)
 {
-    return split ? split->date_reconciled.tv_sec : 0;
+    return split ? split->date_reconciled : 0;
 }
 /*################## Added for Reg2 #################*/
 
@@ -2003,7 +2007,7 @@ xaccSplitAddPeerSplit (Split *split, const Split *other_split,
     guid = qof_instance_get_guid (QOF_INSTANCE (other_split));
     xaccTransBeginEdit (split->parent);
     qof_instance_kvp_add_guid (QOF_INSTANCE (split), "lot-split",
-                               timespec_now(), "peer_guid", guid_copy(guid));
+                               gnc_time(NULL), "peer_guid", guid_copy(guid));
     mark_split (split);
     qof_instance_set_dirty (QOF_INSTANCE (split));
     xaccTransCommitEdit (split->parent);
