@@ -30,19 +30,29 @@ extern "C"
 #include <boost/date_time/gregorian/gregorian.hpp>
 #include <boost/date_time/posix_time/posix_time.hpp>
 #include <boost/date_time/local_time/local_time.hpp>
+#include <boost/locale.hpp>
 #include <boost/regex.hpp>
 #include <libintl.h>
+#include <locale.h>
 #include <map>
 #include <memory>
 #include <iostream>
 #include <sstream>
 #include <string>
 #include <vector>
+#ifdef __MINGW32__
+#include <codecvt>
+#endif
+#include <gnc-locale-utils.hpp>
 #include "gnc-timezone.hpp"
 #include "gnc-datetime.hpp"
+#include "qoflog.h"
+
+static const char* log_module = "gnc.engine";
 
 #define N_(string) string //So that xgettext will find it
 
+using PTZ = boost::local_time::posix_time_zone;
 using Date = boost::gregorian::date;
 using Month = boost::gregorian::greg_month;
 using PTime = boost::posix_time::ptime;
@@ -52,12 +62,18 @@ using LDTBase = boost::local_time::local_date_time_base<PTime, boost::date_time:
 using boost::date_time::not_a_date_time;
 using time64 = int64_t;
 
-static const TimeZoneProvider tzp;
+static const TimeZoneProvider ltzp;
+static const TimeZoneProvider* tzp = &ltzp;
+
 // For converting to/from POSIX time.
 static const PTime unix_epoch (Date(1970, boost::gregorian::Jan, 1),
         boost::posix_time::seconds(0));
 static const TZ_Ptr utc_zone(new boost::local_time::posix_time_zone("UTC-0"));
 
+/* Backdoor to enable unittests to temporarily override the timezone: */
+void _set_tzp(TimeZoneProvider& tz);
+void _reset_tzp();
+
 /* To ensure things aren't overly screwed up by setting the nanosecond clock for boost::date_time. Don't do it, though, it doesn't get us anything and slows down the date/time library. */
 #ifndef BOOST_DATE_TIME_HAS_NANOSECONDS
 static constexpr auto ticks_per_second = INT64_C(1000000);
@@ -146,7 +162,7 @@ LDT_from_unix_local(const time64 time)
         PTime temp(unix_epoch.date(),
                    boost::posix_time::hours(time / 3600) +
                    boost::posix_time::seconds(time % 3600));
-        auto tz = tzp.get(temp.date().year());
+        auto tz = tzp->get(temp.date().year());
         return LDT(temp, tz);
     }
     catch(boost::gregorian::bad_year&)
@@ -154,71 +170,135 @@ LDT_from_unix_local(const time64 time)
         throw(std::invalid_argument("Time value is outside the supported year range."));
     }
 }
+/* If a date-time falls in a DST transition the LDT constructor will
+ * fail because either the date-time doesn't exist (when starting DST
+ * because the transition skips an hour) or is ambiguous (when ending
+ * because the transition hour is repeated). We try again an hour
+ * later to be outside the DST transition. When starting DST that's
+ * now the correct time but at the end of DST we need to set the
+ * returned time back an hour.
+ */
+static LDT
+LDT_with_pushup(const Date& tdate, const Duration& tdur, const TZ_Ptr tz,
+                 bool putback)
+{
+    static const boost::posix_time::hours pushup{1};
+    LDT ldt{tdate, tdur + pushup, tz, LDTBase::NOT_DATE_TIME_ON_ERROR};
+    if (ldt.is_special())
+    {
+        std::string error{"Couldn't create a valid datetime at "};
+        error += to_simple_string(tdate) + " ";
+        error += to_simple_string(tdur) + " TZ ";
+        error += tz->std_zone_abbrev();
+        throw(std::invalid_argument{error});
+    }
+    if (putback)
+        ldt -= pushup;
+    return ldt;
+}
 
 static LDT
-LDT_from_struct_tm(const struct tm tm)
+LDT_from_date_time(const Date& tdate, const Duration& tdur, const TZ_Ptr tz)
 {
-    auto tdate = boost::gregorian::date_from_tm(tm);
-    auto tdur = boost::posix_time::time_duration(tm.tm_hour, tm.tm_min,
-                                                 tm.tm_sec, 0);
-    auto tz = tzp.get(tdate.year());
+
     try
     {
         LDT ldt(tdate, tdur, tz, LDTBase::EXCEPTION_ON_ERROR);
         return ldt;
     }
+    catch (const boost::local_time::time_label_invalid& err)
+    {
+        return LDT_with_pushup(tdate, tdur, tz, false);
+    }
+
+    catch (const boost::local_time::ambiguous_result& err)
+    {
+        return LDT_with_pushup(tdate, tdur, tz, true);
+    }
+
     catch(boost::gregorian::bad_year&)
     {
         throw(std::invalid_argument("Time value is outside the supported year range."));
     }
-    catch(boost::local_time::time_label_invalid&)
+
+}
+
+static LDT
+LDT_from_date_daypart(const Date& date, DayPart part, const TZ_Ptr tz)
+{
+    using hours = boost::posix_time::hours;
+
+    static const Duration day_begin{0, 0, 0};
+    static const Duration day_neutral{10, 59, 0};
+    static const Duration day_end{23, 59, 59};
+
+
+    switch (part)
     {
-        throw(std::invalid_argument("Struct tm does not resolve to a valid time."));
-    }
-    catch(boost::local_time::ambiguous_result&)
-    {
-        /* We plunked down in the middle of a DST change. Try constructing the
-         * LDT three hours later to get a valid result then back up those three
-         * hours to have the time we want.
-         */
-        using boost::posix_time::hours;
-        auto hour = tm.tm_hour;
-        tdur += hours(3);
-        LDT ldt(tdate, tdur, tz, LDTBase::NOT_DATE_TIME_ON_ERROR);
-        if (ldt.is_special())
-            throw(std::invalid_argument("Couldn't create a valid datetime."));
-        ldt -= hours(3);
-        return ldt;
+    case DayPart::start:
+        return LDT_from_date_time(date, day_begin, tz);
+    case DayPart::end:
+        return LDT_from_date_time(date, day_end, tz);
+    default: // To stop gcc from emitting a control reaches end of non-void function.
+    case DayPart::neutral:
+        PTime pt{date, day_neutral};
+        LDT lt{pt, tz};
+        auto offset = lt.local_time() - lt.utc_time();
+        if (offset < hours(-10))
+            lt -= hours(offset.hours() + 10);
+        if (offset > hours(13))
+            lt += hours(13 - offset.hours());
+        return lt;
     }
 }
 
-using TD = boost::posix_time::time_duration;
+static LDT
+LDT_from_struct_tm(const struct tm tm)
+{
+    Date tdate{boost::gregorian::date_from_tm(tm)};
+    Duration tdur{boost::posix_time::time_duration(tm.tm_hour, tm.tm_min,
+                                                  tm.tm_sec, 0)};
+    TZ_Ptr tz{tzp->get(tdate.year())};
+    return LDT_from_date_time(tdate, tdur, tz);
+}
+
+void
+_set_tzp(TimeZoneProvider& new_tzp)
+{
+    tzp = &new_tzp;
+}
+
+void
+_reset_tzp()
+{
+    tzp = &ltzp;
+}
 
 class GncDateTimeImpl
 {
 public:
-    GncDateTimeImpl() : m_time(boost::local_time::local_sec_clock::local_time(tzp.get(boost::gregorian::day_clock::local_day().year()))) {}
+    GncDateTimeImpl() : m_time(boost::local_time::local_sec_clock::local_time(tzp->get(boost::gregorian::day_clock::local_day().year()))) {}
     GncDateTimeImpl(const time64 time) : m_time(LDT_from_unix_local(time)) {}
     GncDateTimeImpl(const struct tm tm) : m_time(LDT_from_struct_tm(tm)) {}
     GncDateTimeImpl(const GncDateImpl& date, DayPart part = DayPart::neutral);
     GncDateTimeImpl(std::string str);
-    GncDateTimeImpl(PTime&& pt) : m_time(pt, tzp.get(pt.date().year())) {}
+    GncDateTimeImpl(PTime&& pt) : m_time(pt, tzp->get(pt.date().year())) {}
     GncDateTimeImpl(LDT&& ldt) : m_time(ldt) {}
 
     operator time64() const;
     operator struct tm() const;
-    void now() { m_time = boost::local_time::local_sec_clock::local_time(tzp.get(boost::gregorian::day_clock::local_day().year())); }
+    void now() { m_time = boost::local_time::local_sec_clock::local_time(tzp->get(boost::gregorian::day_clock::local_day().year())); }
     long offset() const;
     struct tm utc_tm() const { return to_tm(m_time.utc_time()); }
     std::unique_ptr<GncDateImpl> date() const;
     std::string format(const char* format) const;
     std::string format_zulu(const char* format) const;
+    std::string format_iso8601() const;
+    static std::string timestamp();
 private:
     LDT m_time;
-    static const TD time_of_day[3];
 };
 
-const TD GncDateTimeImpl::time_of_day[3] = {TD(0, 0, 0), TD(10, 59, 0), TD(23, 59, 59)};
 /** Private implementation of GncDate. See the documentation for that class.
  */
 class GncDateImpl
@@ -233,7 +313,9 @@ public:
     void today() { m_greg = boost::gregorian::day_clock::local_day(); }
     ymd year_month_day() const;
     std::string format(const char* format) const;
-    std::string format_zulu(const char* format) const;
+    std::string format_zulu(const char* format) const {
+	return this->format(format);
+    }
 private:
     Date m_greg;
 
@@ -246,35 +328,16 @@ private:
     friend bool operator!=(const GncDateImpl&, const GncDateImpl&);
 };
 
+/* Needs to be separately defined so that the friend decl can grant
+ * access to date.m_greg.
+ */
+GncDateTimeImpl::GncDateTimeImpl(const GncDateImpl& date, DayPart part) :
+    m_time{LDT_from_date_daypart(date.m_greg, part,
+                                 tzp->get(date.m_greg.year()))} {}
+
 /* Member function definitions for GncDateTimeImpl.
  */
 
-GncDateTimeImpl::GncDateTimeImpl(const GncDateImpl& date, DayPart part) :
-    m_time(date.m_greg, time_of_day[part], tzp.get(date.m_greg.year()),
-                     LDT::NOT_DATE_TIME_ON_ERROR)
-{
-    using boost::posix_time::hours;
-    try
-    {
-        if (part == DayPart::neutral)
-        {
-            auto offset = m_time.local_time() - m_time.utc_time();
-            m_time = LDT(date.m_greg, time_of_day[part], utc_zone,
-                         LDT::EXCEPTION_ON_ERROR);
-            if (offset < hours(-10))
-                m_time -= hours(offset.hours() + 10);
-            if (offset > hours(13))
-                m_time -= hours(offset.hours() - 11);
-        }
-    }
-    catch(boost::gregorian::bad_year&)
-    {
-        throw(std::invalid_argument("Time value is outside the supported year range."));
-    }
-}
-
-using PTZ = boost::local_time::posix_time_zone;
-
 static TZ_Ptr
 tz_from_string(std::string str)
 {
@@ -318,8 +381,7 @@ GncDateTimeImpl::GncDateTimeImpl(std::string str) :
         if (sm[2].matched)
             tzstr += sm[2];
         tzptr = tz_from_string(tzstr);
-        m_time = LDT(pdt.date(), pdt.time_of_day(), tzptr,
-                         LDTBase::NOT_DATE_TIME_ON_ERROR);
+        m_time = LDT_from_date_time(pdt.date(), pdt.time_of_day(), tzptr);
     }
     catch(boost::gregorian::bad_year&)
     {
@@ -366,28 +428,130 @@ GncDateTimeImpl::date() const
     return std::unique_ptr<GncDateImpl>(new GncDateImpl(m_time.local_time().date()));
 }
 
+/* The 'O', 'E', and '-' format modifiers are not supported by
+ * boost's output facets. Remove them.
+ */
+static inline std::string
+normalize_format (const std::string& format)
+{
+    bool is_pct = false;
+    std::string normalized;
+    std::remove_copy_if(
+        format.begin(), format.end(), back_inserter(normalized),
+        [&is_pct](char e){
+            bool r = (is_pct && (e == 'E' || e == 'O' || e == '-'));
+            is_pct = e == '%';
+            return r;
+        });
+    return normalized;
+}
+#ifdef __MINGW32__
+constexpr size_t DATEBUFLEN = 100;
+static std::string
+win_date_format(std::string format, struct tm tm)
+{
+    wchar_t buf[DATEBUFLEN];
+    memset(buf, 0, DATEBUFLEN);
+    std::wstring_convert<std::codecvt_utf8_utf16<wchar_t>, wchar_t> conv;
+    auto numchars = wcsftime(buf, DATEBUFLEN - 1, conv.from_bytes(format).c_str(), &tm);
+    return conv.to_bytes(buf);
+}
+
+/* Microsoft's strftime uses the time zone flags differently from
+ * boost::date_time so we need to handle any before passing the
+ * format string to strftime.
+ */
+inline std::string
+win_format_tz_abbrev (std::string format, TZ_Ptr tz, bool is_dst)
+{
+    size_t pos = format.find("%z");
+    if (pos != std::string::npos)
+    {
+	auto tzabbr = tz->has_dst() && is_dst ? tz->dst_zone_abbrev() :
+	    tz->std_zone_abbrev();
+	format.replace(pos, 2, tzabbr);
+    }
+    return format;
+}
+
+inline std::string
+win_format_tz_name (std::string format, TZ_Ptr tz, bool is_dst)
+{
+    size_t pos = format.find("%Z");
+    if (pos != std::string::npos)
+    {
+	auto tzname =  tz->has_dst() && is_dst ? tz->dst_zone_name() :
+	    tz->std_zone_name();
+	format.replace(pos, 2, tzname);
+    }
+    return format;
+}
+
+inline std::string
+win_format_tz_posix (std::string format, TZ_Ptr tz)
+{
+    size_t pos = format.find("%ZP");
+    if (pos != std::string::npos)
+	format.replace(pos, 2, tz->to_posix_string());
+    return format;
+}
+
+#endif
 std::string
 GncDateTimeImpl::format(const char* format) const
 {
+#ifdef __MINGW32__
+    auto tz = m_time.zone();
+    auto tm =  static_cast<struct tm>(*this);
+    auto sformat = win_format_tz_abbrev(format, tz, tm.tm_isdst);
+    sformat = win_format_tz_name(sformat, tz, tm.tm_isdst);
+    sformat = win_format_tz_posix(sformat, tz);
+    return win_date_format(sformat, tm);
+#else
     using Facet = boost::local_time::local_time_facet;
+    auto output_facet(new Facet(normalize_format(format).c_str()));
     std::stringstream ss;
-    //The stream destructor frees the facet, so it must be heap-allocated.
-    auto output_facet(new Facet(format));
-    ss.imbue(std::locale(std::locale(), output_facet));
+    ss.imbue(std::locale(gnc_get_locale(), output_facet));
     ss << m_time;
     return ss.str();
+#endif
 }
 
 std::string
 GncDateTimeImpl::format_zulu(const char* format) const
 {
-    using Facet = boost::posix_time::time_facet;
+#ifdef __MINGW32__
+    auto tz = m_time.zone();
+    auto tm =  static_cast<struct tm>(*this);
+    auto sformat = win_format_tz_abbrev(format, tz, tm.tm_isdst);
+    sformat = win_format_tz_name(sformat, tz, tm.tm_isdst);
+    sformat = win_format_tz_posix(sformat, tz);
+    return win_date_format(sformat, utc_tm());
+#else
+    using Facet = boost::local_time::local_time_facet;
+    auto zulu_time = LDT{m_time.utc_time(), utc_zone};
+    auto output_facet(new Facet(normalize_format(format).c_str()));
     std::stringstream ss;
-    //The stream destructor frees the facet, so it must be heap-allocated.
-    auto output_facet(new Facet(format));
-    ss.imbue(std::locale(std::locale(), output_facet));
-    ss << m_time.utc_time();
+    ss.imbue(std::locale(gnc_get_locale(), output_facet));
+    ss << zulu_time;
     return ss.str();
+#endif
+}
+
+std::string
+GncDateTimeImpl::format_iso8601() const
+{
+    auto str = boost::posix_time::to_iso_extended_string(m_time.utc_time());
+    str[10] = ' ';
+    return str.substr(0, 19);
+}
+
+std::string
+GncDateTimeImpl::timestamp()
+{
+    GncDateTimeImpl gdt;
+    auto str = boost::posix_time::to_iso_string(gdt.m_time.local_time());
+    return str.substr(0, 8) + str.substr(9, 15);
 }
 
 /* Member function definitions for GncDateImpl.
@@ -440,13 +604,17 @@ GncDateImpl::year_month_day() const
 std::string
 GncDateImpl::format(const char* format) const
 {
+#ifdef __MINGW32__
+    return win_date_format(format, to_tm(m_greg));
+#else
     using Facet = boost::gregorian::date_facet;
     std::stringstream ss;
     //The stream destructor frees the facet, so it must be heap-allocated.
-    auto output_facet(new Facet(format));
-    ss.imbue(std::locale(std::locale(), output_facet));
+    auto output_facet(new Facet(normalize_format(format).c_str()));
+    ss.imbue(std::locale(gnc_get_locale(), output_facet));
     ss << m_greg;
     return ss.str();
+#endif
 }
 
 bool operator<(const GncDateImpl& a, const GncDateImpl& b) { return a.m_greg < b.m_greg; }
@@ -517,6 +685,18 @@ GncDateTime::format_zulu(const char* format) const
     return m_impl->format_zulu(format);
 }
 
+std::string
+GncDateTime::format_iso8601() const
+{
+    return m_impl->format_iso8601();
+}
+
+std::string
+GncDateTime::timestamp()
+{
+    return GncDateTimeImpl::timestamp();
+}
+
 /* GncDate */
 GncDate::GncDate() : m_impl{new GncDateImpl} {}
 GncDate::GncDate(int year, int month, int day) :
