@@ -200,7 +200,7 @@ gboolean gncEntryPaymentStringToType (const char *str, GncEntryPaymentType *type
 	member = tmp; \
 	}
 
-G_INLINE_FUNC void mark_entry (GncEntry *entry);
+static inline void mark_entry (GncEntry *entry);
 void mark_entry (GncEntry *entry)
 {
     qof_instance_set_dirty(&entry->inst);
@@ -1088,7 +1088,7 @@ GncOrder * gncEntryGetOrder (const GncEntry *entry)
  * to let a consumer know how much they saved.
  *
  * Note this function will not do any rounding unless forced to prevent overflow.
- * It's the caller's responsability to round to the proper commodity
+ * It's the caller's responsibility to round to the proper commodity
  * denominator if needed.
  */
 static void gncEntryComputeValueInt (gnc_numeric qty, gnc_numeric price,
@@ -1324,20 +1324,20 @@ gncEntryRecomputeValues (GncEntry *entry)
     /* See if either tax table changed since we last computed values */
     if (entry->i_tax_table)
     {
-        Timespec modtime = gncTaxTableLastModified (entry->i_tax_table);
-        if (entry->i_taxtable_modtime != modtime.tv_sec)
+        time64 modtime = gncTaxTableLastModifiedSecs (entry->i_tax_table);
+        if (entry->i_taxtable_modtime != modtime)
         {
             entry->values_dirty = TRUE;
-            entry->i_taxtable_modtime = modtime.tv_sec;
+            entry->i_taxtable_modtime = modtime;
         }
     }
     if (entry->b_tax_table)
     {
-        Timespec modtime = gncTaxTableLastModified (entry->b_tax_table);
-        if (entry->b_taxtable_modtime == modtime.tv_sec)
+        time64 modtime = gncTaxTableLastModifiedSecs (entry->b_tax_table);
+        if (entry->b_taxtable_modtime != modtime)
         {
             entry->values_dirty = TRUE;
-            entry->b_taxtable_modtime = modtime.tv_sec;
+            entry->b_taxtable_modtime = modtime;
         }
     }
 
@@ -1599,7 +1599,7 @@ int gncEntryCompare (const GncEntry *a, const GncEntry *b)
     if (a == b) return 0;
     if (!a && b) return -1;
     if (a && !b) return 1;
-
+    g_assert (a && b);  /* Silence a static analysis warning. */
     if (a->date != b->date) return a->date - b->date;
     if (a->date_entered != b->date_entered) return a->date_entered - b->date_entered;
 
