@@ -27,11 +27,11 @@ extern "C"
 
 #include <sys/types.h>
 #include <time.h>
-#include <glib.h>
 #include <regex.h>
 #include <string.h>
 }
 
+#include <glib.h>
 #include "qof.h"
 #include "qof-backend.hpp"
 #include "qofbook-p.h"
@@ -486,7 +486,7 @@ compile_sort (QofQuerySort *sort, QofIdType obj)
     /* If we have valid parameters, grab the compare function,
      * If not, check if this is the default sort.
      */
-    if (sort->param_fcns)
+    if (sort->param_fcns && resObj)
     {
         /* First, check if this parameter has a sort function override.
          * if not then check if there's a global compare function for the type
@@ -535,7 +535,7 @@ static void compile_terms (QofQuery *q)
              * If not, see if this is the default sort.
              */
 
-            if (qt->param_fcns)
+            if (qt->param_fcns && resObj)
                 qt->pred_fcn = qof_query_core_get_predicate (resObj->param_type);
             else
                 qt->pred_fcn = NULL;
@@ -803,7 +803,6 @@ static GList * qof_query_run_internal (QofQuery *q,
             g_list_free(matching_objects);
             matching_objects = NULL;
         }
-        object_count = q->max_results;
     }
 
     q->changed = 0;
@@ -983,11 +982,11 @@ GSList * qof_query_get_term_type (QofQuery *q, QofQueryParamList *term_param)
         {
             QofQueryTerm *qt = static_cast<QofQueryTerm*>(_and_->data);
             if (!param_list_cmp (term_param, qt->param_list))
-                results = g_slist_append(results, qt->pdata);
+                results = g_slist_prepend (results, qt->pdata);
         }
     }
 
-    return results;
+    return g_slist_reverse (results);
 }
 
 void qof_query_destroy (QofQuery *q)
@@ -1827,9 +1826,12 @@ qof_query_printValueForParam (QofQueryPredData *pd, GString * gs)
     if (!g_strcmp0 (pd->type_name, QOF_TYPE_DATE))
     {
         query_date_t pdata = (query_date_t) pd;
+        char datebuff[MAX_DATE_LENGTH + 1];
+        memset (datebuff, 0, sizeof(datebuff));
+        qof_print_date_buff (datebuff, sizeof(datebuff), pdata->date);
         g_string_append_printf (gs, " Match type %s",
                                 qof_query_printDateMatch (pdata->options));
-        g_string_append_printf (gs, " query_date: %s", gnc_print_date (pdata->date));
+        g_string_append_printf (gs, " query_date: %s", datebuff);
         return;
     }
     if (!g_strcmp0 (pd->type_name, QOF_TYPE_CHAR))
