@@ -14,18 +14,19 @@
  *                                                                  *
  * You should have received a copy of the GNU General Public License*
  * along with this program; if not, you can retrieve it from        *
- * http://www.gnu.org/licenses/old-licenses/gpl-2.0.html            *
+ * https://www.gnu.org/licenses/old-licenses/gpl-2.0.html            *
  * or contact:                                                      *
  *                                                                  *
  * Free Software Foundation           Voice:  +1-617-542-5942       *
  * 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652       *
  * Boston, MA  02110-1301,  USA       gnu@gnu.org                   *
  ********************************************************************/
+#include <glib.h>
+
 extern "C"
 {
 #include <config.h>
 #include <string.h>
-#include <glib.h>
 #include <unittest-support.h>
 /* Add specific headers for this class */
 #include <Split.h>
@@ -35,7 +36,6 @@ extern "C"
 #include <TransactionP.h>
 #include <gnc-lot.h>
 #include <gnc-event.h>
-#include <qofinstance-p.h>
 
 #if defined(__clang__) && (__clang_major__ == 5 || (__clang_major__ == 3 && __clang_minor__ < 5))
 #define USE_CLANG_FUNC_SIG 1
@@ -45,6 +45,7 @@ static const gchar *suitename = "/engine/Split";
 void test_suite_split ( void );
 }
 
+#include <qofinstance-p.h>
 #include <kvp-frame.hpp>
 
 typedef struct
@@ -65,7 +66,7 @@ setup (Fixture *fixture, gconstpointer pData)
     GNCLot *lot = gnc_lot_new (book);
     gnc_numeric value = gnc_numeric_create (123, 240);
     gnc_numeric amount = gnc_numeric_create (321, 1000);
-    Timespec time = timespec_now ();
+    time64 time = gnc_time(NULL);
     Split *gains_split = xaccMallocSplit (book);
     fixture->curr = gnc_commodity_new (book, "Gnu Rand", "CURRENCY", "GNR", "", 240);
     fixture->comm = gnc_commodity_new (book, "Wildebeest Fund", "FUND", "WBFXX", "", 1000);
@@ -201,7 +202,8 @@ test_gnc_split_set_get_property ()
     Account *acc = xaccMallocAccount (book), *racc = NULL;
     GNCLot *lot = gnc_lot_new (book), *rlot = NULL;
     Split *split = xaccMallocSplit (book);
-    Timespec time = timespec_now (), *rtime;
+    time64 time = gnc_time(nullptr);
+    Time64 t = {time}, *rtime;
     char *r_action, *r_memo;
     gnc_numeric value = gnc_numeric_create (123, 100);
     gnc_numeric amount = gnc_numeric_create (321, 100);
@@ -218,7 +220,7 @@ test_gnc_split_set_get_property ()
                   "memo", "bar",
                   "value", &value,
                   "amount", &amount,
-                  "reconcile-date", &time,
+                  "reconcile-date", &t,
                   "account", acc,
                   "lot", lot,
                   "transaction", txn,
@@ -240,7 +242,7 @@ test_gnc_split_set_get_property ()
     g_assert (gnc_numeric_equal (*r_value, value));
     /* Setting the transaction causes the amount to be scrubbed into the value */
     g_assert (gnc_numeric_equal (*r_amount, value));
-    g_assert (timespec_equal (rtime, &time));
+    g_assert_cmpint (rtime->t, ==, time);
     g_assert (txn == rtxn);
     g_assert (acc == racc);
     g_assert (lot == rlot);
@@ -302,7 +304,7 @@ test_xaccDupeSplit (Fixture *fixture, gconstpointer pData)
     g_assert_cmpstr (split->action, ==, f_split->action);
     g_assert (compare (split->inst.kvp_data, f_split->inst.kvp_data) == 0);
     g_assert_cmpint (split->reconciled, ==, f_split->reconciled);
-    g_assert (timespec_equal (&(split->date_reconciled), &(f_split->date_reconciled)));
+    g_assert_cmpint (split->date_reconciled, ==, f_split->date_reconciled);
     g_assert (gnc_numeric_equal (split->value, f_split->value));
     g_assert (gnc_numeric_equal (split->amount, f_split->amount));
     /* xaccDupeSplit intentionally doesn't copy the balances */
@@ -337,7 +339,7 @@ test_xaccSplitCloneNoKvp (Fixture *fixture, gconstpointer pData)
     g_assert_cmpstr (split->action, ==, f_split->action);
     g_assert (split->inst.kvp_data->empty());
     g_assert_cmpint (split->reconciled, ==, f_split->reconciled);
-    g_assert (timespec_equal (&(split->date_reconciled), &(f_split->date_reconciled)));
+    g_assert_cmpint (split->date_reconciled, == , f_split->date_reconciled);
     g_assert (gnc_numeric_equal (split->value, f_split->value));
     g_assert (gnc_numeric_equal (split->amount, f_split->amount));
     g_assert (gnc_numeric_equal (split->balance, f_split->balance));
@@ -735,12 +737,12 @@ test_xaccSplitDetermineGainStatus (Fixture *fixture, gconstpointer pData)
 
     fixture->split->gains = GAINS_STATUS_UNKNOWN;
     fixture->split->gains_split = NULL;
-    g_assert (fixture->split->inst.kvp_data->get_slot("gains_source") == NULL);
+    g_assert (fixture->split->inst.kvp_data->get_slot({"gains_source"}) == NULL);
     xaccSplitDetermineGainStatus (fixture->split);
     g_assert (fixture->split->gains_split == NULL);
     g_assert_cmpint (fixture->split->gains, ==, GAINS_STATUS_A_VDIRTY | GAINS_STATUS_DATE_DIRTY);
 
-    fixture->split->inst.kvp_data->set("gains-source", new KvpValue(const_cast<GncGUID*>(guid_copy(g_guid))));
+    fixture->split->inst.kvp_data->set({"gains-source"}, new KvpValue(guid_copy(g_guid)));
     g_assert (fixture->split->gains_split == NULL);
     fixture->split->gains = GAINS_STATUS_UNKNOWN;
     xaccSplitDetermineGainStatus (fixture->split);
@@ -758,10 +760,10 @@ test_get_currency_denom (Fixture *fixture, gconstpointer pData)
     const gint denom = gnc_commodity_get_fraction (fixture->curr);
     g_assert_cmpint (fixture->func->get_currency_denom (NULL), ==, 0);
     fixture->split->parent = NULL;
-    g_assert_cmpint (fixture->func->get_currency_denom (fixture->split), ==, 1000000);
+    g_assert_cmpint (fixture->func->get_currency_denom (fixture->split), ==, GNC_COMMODITY_MAX_FRACTION);
     fixture->split->parent = txn;
     txn->common_currency = NULL;
-    g_assert_cmpint (fixture->func->get_currency_denom (fixture->split), ==, 1000000);
+    g_assert_cmpint (fixture->func->get_currency_denom (fixture->split), ==, GNC_COMMODITY_MAX_FRACTION);
     txn->common_currency = fixture->curr;
     g_assert_cmpint (fixture->func->get_currency_denom (fixture->split), ==, denom);
 }
@@ -776,7 +778,7 @@ test_get_commodity_denom (Fixture *fixture, gconstpointer pData)
     const gint denom = gnc_commodity_get_fraction (fixture->comm);
     g_assert_cmpint (fixture->func->get_commodity_denom (NULL), ==, 0);
     fixture->split->acc = NULL;
-    g_assert_cmpint (fixture->func->get_commodity_denom (fixture->split), ==, 1000000);
+    g_assert_cmpint (fixture->func->get_commodity_denom (fixture->split), ==, GNC_COMMODITY_MAX_FRACTION);
     fixture->split->acc = acc;
     g_assert_cmpint (fixture->func->get_commodity_denom (fixture->split), ==, denom);
 }
@@ -1125,7 +1127,7 @@ test_xaccSplitOrder (Fixture *fixture, gconstpointer pData)
      * split-action based on book option.
      */
     o_split->parent = o_txn;
-    split->parent->date_posted = timespec_now ();
+    split->parent->date_posted = gnc_time (NULL);
     o_split->parent->date_posted = split->parent->date_posted;
 
     /* The book_use_split_action_for_num_field book option hasn't been set so it
@@ -1203,14 +1205,14 @@ test_xaccSplitOrder (Fixture *fixture, gconstpointer pData)
     o_split->value = split->value;
     /* Make sure that it doesn't crash if o_split->date_reconciled == NULL */
     g_assert_cmpint (xaccSplitOrder (split, o_split), ==, 1);
-    o_split->date_reconciled = timespec_now();
-    o_split->date_reconciled.tv_sec -= 50;
+    o_split->date_reconciled = gnc_time(NULL);
+    o_split->date_reconciled -= 50;
     g_assert_cmpint (xaccSplitOrder (split, o_split), ==, 1);
-    o_split->date_reconciled.tv_sec += 100;
+    o_split->date_reconciled += 100;
     g_assert_cmpint (xaccSplitOrder (split, o_split), ==, -1);
 
-    o_split->date_reconciled.tv_sec = split->date_reconciled.tv_sec;
-    o_split->date_reconciled.tv_nsec = split->date_reconciled.tv_nsec;
+    o_split->date_reconciled = split->date_reconciled;
+    o_split->date_reconciled = split->date_reconciled;
 
     g_assert_cmpint (xaccSplitOrder (split, o_split), ==,
                      qof_instance_guid_compare (split, o_split));
@@ -1249,13 +1251,13 @@ test_xaccSplitOrderDateOnly (Fixture *fixture, gconstpointer pData)
     g_assert_cmpint (xaccSplitOrderDateOnly (split, o_split), ==, 1);
     split->parent = txn;
 
-    txn->date_posted = timespec_now ();
-    o_txn->date_posted = timespec_now ();
-    o_txn->date_posted.tv_sec -= 50;
+    txn->date_posted = gnc_time (nullptr);
+    o_txn->date_posted = gnc_time (nullptr);
+    o_txn->date_posted -= 50;
     g_assert_cmpint (xaccSplitOrderDateOnly (split, o_split), ==, 1);
-    o_txn->date_posted.tv_sec += 100;
+    o_txn->date_posted += 100;
     g_assert_cmpint (xaccSplitOrderDateOnly (split, o_split), ==, -1);
-    o_txn->date_posted.tv_sec -= 50;
+    o_txn->date_posted -= 50;
     g_assert_cmpint (xaccSplitOrderDateOnly (split, o_split), ==, -1);
 
     test_destroy (o_split);
@@ -1670,7 +1672,6 @@ test_xaccSplitGetSharePrice (Fixture *fixture, gconstpointer pData)
     gnc_numeric expected = gnc_numeric_create (1, 1);
     Split *split = fixture->split;
     /* Warning: this is a define in Split.c */
-    const guint PRICE_SIGFIGS = 6;
     char *logdomain = "gnc.engine";
     GLogLevelFlags loglevel = static_cast<GLogLevelFlags>(G_LOG_LEVEL_CRITICAL | G_LOG_FLAG_FATAL);
     TestErrorStruct check = { loglevel, logdomain, NULL, 0 };
@@ -1685,7 +1686,6 @@ test_xaccSplitGetSharePrice (Fixture *fixture, gconstpointer pData)
 
     expected = gnc_numeric_div (split->value, split->amount,
                                 GNC_DENOM_AUTO,
-                                GNC_HOW_DENOM_SIGFIGS (PRICE_SIGFIGS) |
                                 GNC_HOW_RND_ROUND_HALF_UP);
 
     result = xaccSplitGetSharePrice (split);
@@ -1710,7 +1710,6 @@ test_xaccSplitGetSharePrice (Fixture *fixture, gconstpointer pData)
     split->value = gnc_numeric_create (3, 789304166);
     quotient = gnc_numeric_div (split->value, split->amount,
                                 GNC_DENOM_AUTO,
-                                GNC_HOW_DENOM_SIGFIGS (PRICE_SIGFIGS) |
                                 GNC_HOW_RND_ROUND_HALF_UP);
     check.msg = g_strdup_printf ("[xaccSplitGetSharePrice()] "
                                  "Computing share price failed (%d): [ %"
@@ -1730,7 +1729,6 @@ test_xaccSplitGetSharePrice (Fixture *fixture, gconstpointer pData)
     split->value = gnc_numeric_create (3, 0);
     quotient = gnc_numeric_div (split->value, split->amount,
                                 GNC_DENOM_AUTO,
-                                GNC_HOW_DENOM_SIGFIGS (PRICE_SIGFIGS) |
                                 GNC_HOW_RND_ROUND_HALF_UP);
     check.msg = g_strdup_printf ("[xaccSplitGetSharePrice()] "
                                  "Computing share price failed (%d): [ %"
@@ -1750,7 +1748,6 @@ test_xaccSplitGetSharePrice (Fixture *fixture, gconstpointer pData)
     split->value = gnc_numeric_create (3, 789304166);
     quotient = gnc_numeric_div (split->value, split->amount,
                                 GNC_DENOM_AUTO,
-                                GNC_HOW_DENOM_SIGFIGS (PRICE_SIGFIGS) |
                                 GNC_HOW_RND_ROUND_HALF_UP);
     check.msg = g_strdup_printf ("[xaccSplitGetSharePrice()] "
                                  "Computing share price failed (%d): [ %"
@@ -1802,7 +1799,7 @@ test_xaccSplitGetOtherSplit (Fixture *fixture, gconstpointer pData)
     g_assert (xaccSplitGetOtherSplit (split1) == NULL);
 
     g_assert (xaccTransUseTradingAccounts (txn) == FALSE);
-    g_assert (split->inst.kvp_data->get_slot("lot-split") == NULL);
+    g_assert (split->inst.kvp_data->get_slot({"lot-split"}) == NULL);
     g_assert_cmpint (xaccTransCountSplits (txn), !=, 2);
     g_assert (xaccSplitGetOtherSplit (split) == NULL);
 
@@ -1813,18 +1810,18 @@ test_xaccSplitGetOtherSplit (Fixture *fixture, gconstpointer pData)
     xaccSplitSetParent (split2, txn);
     g_assert (xaccSplitGetOtherSplit (split) == NULL);
 
-    split->inst.kvp_data->set("lot-split", kvpnow);
-    g_assert (split->inst.kvp_data->get_slot("lot-split"));
+    split->inst.kvp_data->set({"lot-split"}, kvpnow);
+    g_assert (split->inst.kvp_data->get_slot({"lot-split"}));
     g_assert (xaccSplitGetOtherSplit (split) == NULL);
 
-    split1->inst.kvp_data->set("lot-split", kvpnow);
-    g_assert (split1->inst.kvp_data->get_slot("lot-split"));
+    split1->inst.kvp_data->set({"lot-split"}, kvpnow);
+    g_assert (split1->inst.kvp_data->get_slot({"lot-split"}));
     g_assert (xaccSplitGetOtherSplit (split) == split2);
 
-    split->inst.kvp_data->set("lot-split", NULL);
-    g_assert (split->inst.kvp_data->get_slot("lot-split") == NULL);
-    split1->inst.kvp_data->set("lot-split", NULL);
-    g_assert (split1->inst.kvp_data->get_slot("lot-split") == NULL);
+    split->inst.kvp_data->set({"lot-split"}, NULL);
+    g_assert (split->inst.kvp_data->get_slot({"lot-split"}) == NULL);
+    split1->inst.kvp_data->set({"lot-split"}, NULL);
+    g_assert (split1->inst.kvp_data->get_slot({"lot-split"}) == NULL);
     qof_book_begin_edit (book);
     qof_instance_set (QOF_INSTANCE (book),
 		      "trading-accts", "t",
